@@ -1,4 +1,4 @@
-/* $Id: aghdr.h,v 1.16 2004/12/11 19:26:04 ellson Exp $ $Revision: 1.16 $ */
+/* $Id: aghdr.h,v 1.17 2004/12/19 01:51:03 erg Exp $ $Revision: 1.17 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -83,9 +83,7 @@ extern "C" {
 #define AGNEW(g,t)			((t*)(agalloc(g,sizeof(t))))
 
 #define TAIL_ID				"tailport"
-#define TAILSUB_ID			"_tailsubport"
 #define HEAD_ID				"headport"
-#define HEADSUB_ID			"_headsubport"
 
 #define ISALNUM(c) ((isalnum(c)) || ((c) == '_') || (!isascii(c)))
 
