@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875c.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -107,7 +107,6 @@ typedef struct item_s {		/* generic list */
 	int				tag;	/* T_node, T_subgraph, T_edge, T_attr */
 	val_t			u;		/* primary element */
 	char			*str;	/* secondary value - port or attr value */
-	char			*substr;	/* tertiary value - compass */
 	struct item_s	*next;
 } item;
 
@@ -121,8 +120,8 @@ static void appendnode(char *name, char *port, char *sport);
 static void attrstmt(int tkind, char *macroname);
 static void startgraph(char *name, int directed, int strict);
 static void bufferedges(void);
-static void newedge(Agnode_t *t, char *tport, char* tsport, Agnode_t *h, char *hport, char* hsport, char *key);
-static void edgerhs(Agnode_t *n, char *tport, char *tsport, item *hlist, char *key);
+static void newedge(Agnode_t *t, char *tport, Agnode_t *h, char *hport, char *key);
+static void edgerhs(Agnode_t *n, char *tport, item *hlist, char *key);
 static void appendattr(char *name, char *value);
 static void bindattrs(int kind);
 static void applyattrs(void *obj);
@@ -130,6 +129,7 @@ static void endgraph(void);
 static void endnode(void);
 static void endedge(void);
 static char* concat(char*, char*);
+static char* concatPort(char*, char*);
 
 static void opensubg(char *name);
 static void closesubg(void);
@@ -159,7 +159,7 @@ typedef union YYSTYPE {
 			char			*str;
 			struct Agnode_s	*n;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
+/* Line 190 of yacc.c.  */
 #line 164 "y.tab.c"
 # define aagstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -171,7 +171,7 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
+/* Line 213 of yacc.c.  */
 #line 176 "y.tab.c"
 
 #if ! defined (aagoverflow) || YYERROR_VERBOSE
@@ -187,14 +187,10 @@ typedef union YYSTYPE {
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -220,7 +216,7 @@ typedef union YYSTYPE {
 /* A type that is properly aligned for any stack member.  */
 union aagalloc
 {
-  short aagss;
+  short int aagss;
   YYSTYPE aagvs;
   };
 
@@ -230,7 +226,7 @@ union aagalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
@@ -272,7 +268,7 @@ union aagalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char aagsigned_char;
 #else
-   typedef short aagsigned_char;
+   typedef short int aagsigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -395,7 +391,7 @@ static const char *const aagtname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short aagtoknum[] =
+static const unsigned short int aagtoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   123,   125,    59,    44,    58,    61,
@@ -565,20 +561,53 @@ do								\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `aaglex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -601,19 +630,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (aagdebug)					\
-    aagsymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (aagdebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       aagsymprint (stderr, 					\
-                  Token, Value);	\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -625,12 +648,12 @@ do {								\
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-aag_stack_print (short *bottom, short *top)
+aag_stack_print (short int *bottom, short int *top)
 #else
 static void
 aag_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -680,8 +703,7 @@ do {					\
 int aagdebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -699,10 +721,6 @@ int aagdebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -784,15 +802,15 @@ aagsymprint (aagoutput, aagtype, aagvaluep)
   (void) aagvaluep;
 
   if (aagtype < YYNTOKENS)
-    {
-      YYFPRINTF (aagoutput, "token %s (", aagtname[aagtype]);
-# ifdef YYPRINT
-      YYPRINT (aagoutput, aagtoknum[aagtype], *aagvaluep);
-# endif
-    }
+    YYFPRINTF (aagoutput, "token %s (", aagtname[aagtype]);
   else
     YYFPRINTF (aagoutput, "nterm %s (", aagtname[aagtype]);
 
+
+# ifdef YYPRINT
+  if (aagtype < YYNTOKENS)
+    YYPRINT (aagoutput, aagtoknum[aagtype], *aagvaluep);
+# endif
   switch (aagtype)
     {
       default:
@@ -808,10 +826,11 @@ aagsymprint (aagoutput, aagtype, aagvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-aagdestruct (int aagtype, YYSTYPE *aagvaluep)
+aagdestruct (const char *aagmsg, int aagtype, YYSTYPE *aagvaluep)
 #else
 static void
-aagdestruct (aagtype, aagvaluep)
+aagdestruct (aagmsg, aagtype, aagvaluep)
+    const char *aagmsg;
     int aagtype;
     YYSTYPE *aagvaluep;
 #endif
@@ -819,6 +838,10 @@ aagdestruct (aagtype, aagvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) aagvaluep;
 
+  if (!aagmsg)
+    aagmsg = "Deleting";
+  YY_SYMBOL_PRINT (aagmsg, aagtype, aagvaluep, aaglocationp);
+
   switch (aagtype)
     {
 
@@ -846,10 +869,10 @@ int aagparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int aagchar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE aaglval;
 
 /* Number of syntax errors so far.  */
@@ -885,7 +908,7 @@ aagparse ()
   int aagresult;
   /* Number of tokens to shift before error messages enabled.  */
   int aagerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int aagtoken = 0;
 
   /* Three stacks and their tools:
@@ -897,9 +920,9 @@ aagparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	aagssa[YYINITDEPTH];
-  short *aagss = aagssa;
-  register short *aagssp;
+  short int aagssa[YYINITDEPTH];
+  short int *aagss = aagssa;
+  register short int *aagssp;
 
   /* The semantic value stack.  */
   YYSTYPE aagvsa[YYINITDEPTH];
@@ -936,6 +959,9 @@ aagparse ()
   aagssp = aagss;
   aagvsp = aagvs;
 
+
+  aagvsp[0] = aaglval;
+
   goto aagsetstate;
 
 /*------------------------------------------------------------.
@@ -961,7 +987,7 @@ aagparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *aagvs1 = aagvs;
-	short *aagss1 = aagss;
+	short int *aagss1 = aagss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -989,7 +1015,7 @@ aagparse ()
 	aagstacksize = YYMAXDEPTH;
 
       {
-	short *aagss1 = aagss;
+	short int *aagss1 = aagss;
 	union aagalloc *aagptr =
 	  (union aagalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (aagstacksize));
 	if (! aagptr)
@@ -1025,18 +1051,18 @@ aagparse ()
 aagbackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* aagresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   aagn = aagpact[aagstate];
   if (aagn == YYPACT_NINF)
     goto aagdefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (aagchar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1051,7 +1077,7 @@ aagbackup:
   else
     {
       aagtoken = YYTRANSLATE (aagchar);
-      YYDSYMPRINTF ("Next token is", aagtoken, &aaglval, &aaglloc);
+      YY_SYMBOL_PRINT ("Next token is", aagtoken, &aaglval, &aaglloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1071,8 +1097,8 @@ aagbackup:
   if (aagn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", aagtname[aagtoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", aagtoken, &aaglval, &aaglloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (aagchar != YYEOF)
@@ -1133,42 +1159,42 @@ aagreduce:
 
   case 6:
 #line 97 "../agraph/grammar.y"
-    {startgraph(aagvsp[0].str,aagvsp[-1].i,aagvsp[-2].i);}
+    {startgraph((aagvsp[0].str),(aagvsp[-1].i),(aagvsp[-2].i));}
     break;
 
   case 7:
 #line 100 "../agraph/grammar.y"
-    {aagval.str=aagvsp[0].str;}
+    {(aagval.str)=(aagvsp[0].str);}
     break;
 
   case 8:
 #line 100 "../agraph/grammar.y"
-    {aagval.str=0;}
+    {(aagval.str)=0;}
     break;
 
   case 9:
 #line 102 "../agraph/grammar.y"
-    {aagval.i=1;}
+    {(aagval.i)=1;}
     break;
 
   case 10:
 #line 102 "../agraph/grammar.y"
-    {aagval.i=0;}
+    {(aagval.i)=0;}
     break;
 
   case 11:
 #line 104 "../agraph/grammar.y"
-    {aagval.i = 0;}
+    {(aagval.i) = 0;}
     break;
 
   case 12:
 #line 104 "../agraph/grammar.y"
-    {aagval.i = 1;}
+    {(aagval.i) = 1;}
     break;
 
   case 21:
 #line 117 "../agraph/grammar.y"
-    {if (aagvsp[-1].i) endedge(); else endnode();}
+    {if ((aagvsp[-1].i)) endedge(); else endnode();}
     break;
 
   case 24:
@@ -1178,32 +1204,32 @@ aagreduce:
 
   case 25:
 #line 122 "../agraph/grammar.y"
-    {aagval.i = 1;}
+    {(aagval.i) = 1;}
     break;
 
   case 26:
 #line 123 "../agraph/grammar.y"
-    {aagval.i = 0;}
+    {(aagval.i) = 0;}
     break;
 
   case 29:
 #line 129 "../agraph/grammar.y"
-    {appendnode(aagvsp[0].str,NIL(char*),NIL(char*));}
+    {appendnode((aagvsp[0].str),NIL(char*),NIL(char*));}
     break;
 
   case 30:
 #line 130 "../agraph/grammar.y"
-    {appendnode(aagvsp[-2].str,aagvsp[0].str,NIL(char*));}
+    {appendnode((aagvsp[-2].str),(aagvsp[0].str),NIL(char*));}
     break;
 
   case 31:
 #line 131 "../agraph/grammar.y"
-    {appendnode(aagvsp[-4].str,aagvsp[-2].str,aagvsp[0].str);}
+    {appendnode((aagvsp[-4].str),(aagvsp[-2].str),(aagvsp[0].str));}
     break;
 
   case 32:
 #line 134 "../agraph/grammar.y"
-    {attrstmt(aagvsp[-2].i,aagvsp[-1].str);}
+    {attrstmt((aagvsp[-2].i),(aagvsp[-1].str));}
     break;
 
   case 33:
@@ -1213,42 +1239,42 @@ aagreduce:
 
   case 34:
 #line 138 "../agraph/grammar.y"
-    {aagval.i = T_graph;}
+    {(aagval.i) = T_graph;}
     break;
 
   case 35:
 #line 139 "../agraph/grammar.y"
-    {aagval.i = T_node;}
+    {(aagval.i) = T_node;}
     break;
 
   case 36:
 #line 140 "../agraph/grammar.y"
-    {aagval.i = T_edge;}
+    {(aagval.i) = T_edge;}
     break;
 
   case 37:
 #line 143 "../agraph/grammar.y"
-    {aagval.str = aagvsp[-1].str;}
+    {(aagval.str) = (aagvsp[-1].str);}
     break;
 
   case 38:
 #line 144 "../agraph/grammar.y"
-    {aagval.str = NIL(char*); }
+    {(aagval.str) = NIL(char*); }
     break;
 
   case 47:
 #line 159 "../agraph/grammar.y"
-    {appendattr(aagvsp[-2].str,aagvsp[0].str);}
+    {appendattr((aagvsp[-2].str),(aagvsp[0].str));}
     break;
 
   case 48:
 #line 162 "../agraph/grammar.y"
-    {appendattr(aagvsp[0].str,NIL(char*));}
+    {appendattr((aagvsp[0].str),NIL(char*));}
     break;
 
   case 50:
 #line 168 "../agraph/grammar.y"
-    {opensubg(aagvsp[0].str);}
+    {opensubg((aagvsp[0].str));}
     break;
 
   case 51:
@@ -1258,44 +1284,44 @@ aagreduce:
 
   case 52:
 #line 171 "../agraph/grammar.y"
-    {aagval.str=aagvsp[0].str;}
+    {(aagval.str)=(aagvsp[0].str);}
     break;
 
   case 53:
 #line 172 "../agraph/grammar.y"
-    {aagval.str=NIL(char*);}
+    {(aagval.str)=NIL(char*);}
     break;
 
   case 54:
 #line 173 "../agraph/grammar.y"
-    {aagval.str=NIL(char*);}
+    {(aagval.str)=NIL(char*);}
     break;
 
   case 58:
 #line 178 "../agraph/grammar.y"
-    {aagval.str = aagvsp[0].str;}
+    {(aagval.str) = (aagvsp[0].str);}
     break;
 
   case 59:
 #line 179 "../agraph/grammar.y"
-    {aagval.str = aagvsp[0].str;}
+    {(aagval.str) = (aagvsp[0].str);}
     break;
 
   case 60:
 #line 182 "../agraph/grammar.y"
-    {aagval.str = aagvsp[0].str;}
+    {(aagval.str) = (aagvsp[0].str);}
     break;
 
   case 61:
-#line 184 "../agraph/grammar.y"
-    {aagval.str = concat(aagvsp[-2].str,aagvsp[0].str); agstrfree(G,aagvsp[-2].str); agstrfree(G,aagvsp[0].str);}
+#line 183 "../agraph/grammar.y"
+    {(aagval.str) = concat((aagvsp[-2].str),(aagvsp[0].str));}
     break;
 
 
     }
 
-/* Line 1000 of yacc.c.  */
-#line 1299 "y.tab.c"
+/* Line 1037 of yacc.c.  */
+#line 1325 "y.tab.c"
 
   aagvsp -= aaglen;
   aagssp -= aaglen;
@@ -1395,7 +1421,7 @@ aagerrlab:
 
   if (aagerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (aagchar <= YYEOF)
@@ -1405,23 +1431,22 @@ aagerrlab:
 	  if (aagchar == YYEOF)
 	     for (;;)
 	       {
+
 		 YYPOPSTACK;
 		 if (aagssp == aagss)
 		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", aagstos[*aagssp], aagvsp, aaglsp);
-		 aagdestruct (aagstos[*aagssp], aagvsp);
+		 aagdestruct ("Error: popping",
+                             aagstos[*aagssp], aagvsp);
 	       }
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", aagtoken, &aaglval, &aaglloc);
-	  aagdestruct (aagtoken, &aaglval);
+	  aagdestruct ("Error: discarding", aagtoken, &aaglval);
 	  aagchar = YYEMPTY;
-
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto aagerrlab1;
 
@@ -1438,7 +1463,7 @@ aagerrorlab:
      goto aagerrorlab;
 #endif
 
-  aagvsp -= aaglen;
+aagvsp -= aaglen;
   aagssp -= aaglen;
   aagstate = *aagssp;
   goto aagerrlab1;
@@ -1468,8 +1493,8 @@ aagerrlab1:
       if (aagssp == aagss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", aagstos[*aagssp], aagvsp, aaglsp);
-      aagdestruct (aagstos[aagstate], aagvsp);
+
+      aagdestruct ("Error: popping", aagstos[aagstate], aagvsp);
       YYPOPSTACK;
       aagstate = *aagssp;
       YY_STACK_PRINT (aagss, aagssp);
@@ -1478,11 +1503,12 @@ aagerrlab1:
   if (aagn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++aagvsp = aaglval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", aagstos[aagn], aagvsp, aaglsp);
+
   aagstate = aagn;
   goto aagnewstate;
 
@@ -1498,6 +1524,9 @@ aagacceptlab:
 | aagabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 aagabortlab:
+  aagdestruct ("Error: discarding lookahead",
+              aagtoken, &aaglval);
+  aagchar = YYEMPTY;
   aagresult = 1;
   goto aagreturn;
 
@@ -1520,7 +1549,7 @@ aagreturn:
 }
 
 
-#line 186 "../agraph/grammar.y"
+#line 185 "../agraph/grammar.y"
 
 
 #define NILitem  NIL(item*)
@@ -1530,24 +1559,24 @@ static	Agraph_t	*Subgraph;	/* most recent subgraph that was opened */
 static	Agdisc_t	*Disc;		/* discipline passed to agread or agconcat */
 static	list_t	Nodelist,Edgelist,Attrlist;
 
-static item *newitem(int tag, void *p0, char *p1, char *p2)
+static item *newitem(int tag, void *p0, char *p1)
 {
 	item	*rv = agalloc(G,sizeof(item));
-	rv->tag = tag; rv->u.name = (char*)p0; rv->str = p1; rv->substr = p2;
+	rv->tag = tag; rv->u.name = (char*)p0; rv->str = p1;
 	return rv;
 }
 
-static item *cons_node(Agnode_t *n, char *port, char *sport)
-	{ return newitem(T_node,n,port,sport); }
+static item *cons_node(Agnode_t *n, char *port)
+	{ return newitem(T_node,n,port); }
 
 static item *cons_attr(char *name, char *value)
-	{ return newitem(T_atom,name,value,NIL(char*)); }
+	{ return newitem(T_atom,name,value); }
 
 static item *cons_list(item *list)
-	{ return newitem(T_list,list,NIL(char*),NIL(char*)); }
+	{ return newitem(T_list,list,NIL(char*)); }
 
 static item *cons_subg(Agraph_t *subg)
-	{ return newitem(T_subgraph,subg,NIL(char*),NIL(char*)); }
+	{ return newitem(T_subgraph,subg,NIL(char*)); }
 
 #ifdef NOTDEF
 static item *cons_edge(Agedge_t *e)
@@ -1669,7 +1698,10 @@ static void appendnode(char *name, char *port, char *sport)
 {
 	item		*elt;
 
-	elt = cons_node(agnode(G,name,TRUE),port,sport);
+	if (sport) {
+		port = concatPort (port, sport);
+	}
+	elt = cons_node(agnode(G,name,TRUE),port);
 	listapp(&Nodelist,elt);
 	agstrfree(G,name);
 }
@@ -1723,11 +1755,11 @@ static void endedge(void)
 		if (p->tag == T_subgraph) {
 			subg = p->u.subg;
 			for (t = agfstnode(subg); t; t = agnxtnode(t))
-				edgerhs(agsubnode(G,t,FALSE),NIL(char*),NIL(char*),p->next,key);
+				edgerhs(agsubnode(G,t,FALSE),NIL(char*),p->next,key);
 		}
 		else {
 			for (tptr = p->u.list; tptr; tptr = tptr->next)
-				edgerhs(tptr->u.n,tptr->str,tptr->substr,p->next,key);
+				edgerhs(tptr->u.n,tptr->str,p->next,key);
 		}
 	}
 	deletelist(&Edgelist);
@@ -1755,8 +1787,28 @@ concat (char* s1, char* s2)
   return s;
 }
 
+/* concatPort:
+ */
+static char*
+concatPort (char* s1, char* s2)
+{
+  char*  s;
+  char   buf[BUFSIZ];
+  char*  sym;
+  int    len = strlen(s1) + strlen(s2) + 2;  /* one more for ':' */
 
-static void edgerhs(Agnode_t *tail, char *tport, char* tsport, item *hlist, char *key)
+  if (len <= BUFSIZ) sym = buf;
+  else sym = (char*)malloc(len);
+  sprintf (sym, "%s:%s", s1, s2);
+  s = agstrdup (G,sym);
+  agstrfree (G,s1);
+  agstrfree (G,s2);
+  if (sym != buf) free (sym);
+  return s;
+}
+
+
+static void edgerhs(Agnode_t *tail, char *tport, item *hlist, char *key)
 {
 	Agnode_t		*head;
 	Agraph_t		*subg;
@@ -1765,11 +1817,11 @@ static void edgerhs(Agnode_t *tail, char *tport, char* tsport, item *hlist, char
 	if (hlist->tag == T_subgraph) {
 		subg = hlist->u.subg;
 		for (head = agfstnode(subg); head; head = agnxtnode(head))
-			newedge(tail,tport,tsport,agsubnode(G,head,FALSE),NIL(char*),NIL(char*),key);
+			newedge(tail,tport,agsubnode(G,head,FALSE),NIL(char*),key);
 	}
 	else {
 		for (hptr = hlist->u.list; hptr; hptr = hptr->next)
-			newedge(tail,tport,tsport,agsubnode(G,hptr->u.n,FALSE),hptr->str,hptr->substr,key);
+			newedge(tail,tport,agsubnode(G,hptr->u.n,FALSE),hptr->str,key);
 	}
 }
 
@@ -1783,7 +1835,7 @@ static void mkport(Agedge_t *e, char *name, char *val)
 	}
 }
 
-static void newedge(Agnode_t *t, char *tport, char* tsport, Agnode_t *h, char *hport, char* hsport, char *key)
+static void newedge(Agnode_t *t, char *tport, Agnode_t *h, char *hport, char *key)
 {
 	Agedge_t 	*e;
 
@@ -1791,18 +1843,13 @@ static void newedge(Agnode_t *t, char *tport, char* tsport, Agnode_t *h, char *h
 	if (e) {		/* can fail if graph is strict and t==h */
 		char    *tp = tport;
 		char    *hp = hport;
-		char    *tsp = tsport;
-		char    *hsp = hsport;
 		if ((agtail(e) != aghead(e)) && (aghead(e) == t)) {
 			/* could happen with an undirected edge */
 			char    *temp;
 			temp = tp; tp = hp; hp = temp;
-			temp = tsp; tsp = hsp; hsp = temp;
 		}
 		mkport(e,TAIL_ID,tp);
 		mkport(e,HEAD_ID,hp);
-		mkport(e,TAILSUB_ID,tsp);
-		mkport(e,HEADSUB_ID,hsp);
 		applyattrs(e);
 	}
 }
