@@ -1,4 +1,4 @@
-/* $Id: gdgen.c,v 1.170 2004/12/12 13:55:58 ellson Exp $ $Revision: 1.170 $ */
+/* $Id: gdgen.c,v 1.171 2005/04/05 18:31:14 ellson Exp $ $Revision: 1.171 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -534,8 +534,9 @@ char *gd_alternate_fontlist(char *font)
 
     fontlist = fontbuf;
     if ((strcasecmp(font, "times-bold") == 0)
+	|| (strcasecmp(fontbuf, "timesbd") == 0)
 	|| (strcasecmp(fontbuf, "timesb") == 0))
-	fontlist = "timesb;Timesb;TIMESB";
+	fontlist = "timesbd;Timesbd;TIMESBD;timesb;Timesb;TIMESB";
 
     else if ((strcasecmp(font, "times-italic") == 0)
 	     || (strcasecmp(fontbuf, "timesi") == 0))
