@@ -1,4 +1,4 @@
-/* $Id: htmltable.c,v 1.36 2004/12/11 19:26:05 ellson Exp $ $Revision: 1.36 $ */
+/* $Id: htmltable.c,v 1.38 2005/01/11 22:51:56 erg Exp $ $Revision: 1.38 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -422,6 +422,12 @@ void free_html_text(htmltxt_t * tp)
     free(tp);
 }
 
+void free_html_img(htmlimg_t * ip)
+{
+    free(ip->src);
+    free(ip);
+}
+
 static void free_html_cell(htmlcell_t * cp)
 {
     free_html_label(&cp->child, 0);
@@ -461,6 +467,8 @@ void free_html_label(htmllabel_t * lp, int root)
 {
     if (lp->kind == HTML_TBL)
 	free_html_tbl(lp->u.tbl);
+    else if (lp->kind == HTML_IMAGE)
+	free_html_img(lp->u.img);
     else
 	free_html_text(lp->u.txt);
     if (root)
@@ -1462,5 +1470,14 @@ int make_html_label(textlabel_t * lp, void *obj)
 	lp->dimen.y = box.UR.y - box.LL.y;
     }
     lp->u.html = lbl;
+
+    /* If the label is a table, replace label text because this may
+     * be used for the title and alt fields in image maps.
+     */
+    if (lbl->kind == HTML_TBL) {
+	free (lp->text);
+	lp->text = strdup ("<TABLE>");
+    }
+
     return rv;
 }
