@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.82 2004/12/11 19:26:05 ellson Exp $ $Revision: 1.82 $ */
+/* $Id: input.c,v 1.83 2005/03/26 16:38:20 ellson Exp $ $Revision: 1.83 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -338,9 +338,6 @@ graph_t *next_input_graph(void)
 
 void graph_init(graph_t * g)
 {
-#if ENABLE_CODEGENS && !defined(HAVE_GD_FREETYPE)
-    initDPI(g);
-#endif
     /* initialize the graph */
     init_ugraph(g);
 
@@ -480,7 +477,6 @@ void init_ugraph(graph_t * g)
 	else if (streq(p, "RL"))
 	    GD_rankdir(g) = RANKDIR_RL;
     }
-    do_graph_label(g);
     xf = late_double(g, agfindattr(g, "nodesep"), DEFAULT_NODESEP,
 		     MIN_NODESEP);
     GD_nodesep(g) = POINTS(xf);
@@ -526,6 +522,13 @@ void init_ugraph(graph_t * g)
 	|| ((p = agget(g, "resolution")) && p[0]))
 	GD_drawing(g)->dpi = atof(p);
 
+    /* The following two functions rely on dpi being set */
+#if !defined(DISABLE_CODEGENS) && !defined(HAVE_GD_FREETYPE)
+    if (GD_drawing(g)->dpi < 1.0) GD_drawing(g)->dpi = DEFAULT_DPI;
+    initDPI(g);
+#endif
+    do_graph_label(g);
+
     Nodesep = 1.0;
     Nodefactor = 1.0;
     Initial_dist = MYHUGE;
