@@ -1,4 +1,4 @@
-/* $Id: ns.c,v 1.3 2004/12/11 19:26:05 ellson Exp $ $Revision: 1.3 $ */
+/* $Id: ns.c,v 1.4 2005/04/05 20:32:49 ellson Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -298,14 +298,14 @@ static void init_cutvalues(void)
     dfs_cutval(GD_nlist(G), NULL);
 }
 
-static void feasible_tree(void)
+static int feasible_tree(void)
 {
     int i, delta;
     node_t *n;
     edge_t *e, *f;
 
     if (N_nodes <= 1)
-	return;
+	return 0;
     while (tight_tree() < N_nodes) {
 	e = NULL;
 	for (n = GD_nlist(G); n; n = ND_next(n)) {
@@ -337,10 +337,11 @@ static void feasible_tree(void)
 		    fprintf(stderr, "\t%s\n", n->name);
 	    }
 #endif
-	    abort();
+	    return 1;
 	}
     }
     init_cutvalues();
+    return 0;
 }
 
 /* walk up from v to LCA(v,w), setting new cutvalues. */
@@ -384,7 +385,8 @@ static void rerank(node_t * v, int delta)
 /* e is the tree edge that is leaving and f is the nontree edge that
  * is entering.  compute new cut values, ranks, and exchange e and f.
  */
-void update(edge_t * e, edge_t * f)
+static void 
+update(edge_t * e, edge_t * f)
 {
     int cutvalue, delta;
     node_t *lca;
@@ -564,8 +566,10 @@ static int init_graph(graph_t * g)
  *   Out and in edges lists stored in ND_out and ND_in, even if the node
  *  doesn't have any out or in edges.
  * The node rank values are stored in ND_rank.
+ * Returns 0 if successful; returns 1 if not, the latter indicating that
+ * the graph was not connected.
  */
-void rank(graph_t * g, int balance, int maxiter)
+int rank(graph_t * g, int balance, int maxiter)
 {
     int iter = 0, feasible;
     char *s, *ns = "network simplex: ";
@@ -577,14 +581,14 @@ void rank(graph_t * g, int balance, int maxiter)
     if (!feasible)
 	init_rank();
     if (maxiter <= 0)
-	return;
+	return 0;
 
     if ((s = agget(g, "searchsize")))
 	Search_size = atoi(s);
     else
 	Search_size = SEARCHSIZE;
 
-    feasible_tree();
+    if (feasible_tree()) return 1;
     while ((e = leave_edge())) {
 	f = enter_edge(e);
 	update(e, f);
@@ -616,6 +620,7 @@ void rank(graph_t * g, int balance, int maxiter)
 	fprintf(stderr, "%s%d nodes %d edges %d iter %.2f sec\n",
 		ns, N_nodes, N_edges, iter, elapsed_sec());
     }
+    return 0;
 }
 
 /* set cut value of f, assuming values of edges on one side were already set */
