@@ -1,4 +1,4 @@
-/* $Id: psgen.c,v 1.64 2004/12/11 19:26:05 ellson Exp $ $Revision: 1.64 $ */
+/* $Id: psgen.c,v 1.65 2004/12/15 00:05:28 erg Exp $ $Revision: 1.65 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -534,7 +534,7 @@ static void ps_textline(point p, textline_t * line)
 
     if (S[SP].invis)
 	return;
-    if (S[SP].pencolor == '\0')
+    if (*S[SP].pencolor == '\0')
 	return;
     if (line->xshow) {
 	switch (line->just) {
@@ -574,7 +574,7 @@ ps_bezier(point * A, int n, int arrow_at_start, int arrow_at_end)
     int j;
     if (S[SP].invis)
 	return;
-    if (S[SP].pencolor == '\0')
+    if (*S[SP].pencolor == '\0')
 	return;
     if (arrow_at_start || arrow_at_end)
 	agerr(AGERR, "ps_bezier illegal arrow args\n");
@@ -592,17 +592,17 @@ static void ps_polygon(point * A, int n, int filled)
 
     if (S[SP].invis)
 	return;
-    if (filled && S[SP].fillcolor) {
+    if (filled && *S[SP].fillcolor) {
 	ps_set_color(S[SP].fillcolor);
 	fprintf(Output_file, Newpath_Moveto, A[0].x, A[0].y);
 	for (j = 1; j < n; j++)
 	    fprintf(Output_file, "%d %d lineto\n", A[j].x, A[j].y);
 	fprintf(Output_file, "closepath\n");
 	fprintf(Output_file, Fill);
-	if (S[SP].pencolor)
+	if (*S[SP].pencolor)
 	    ps_set_color(S[SP].pencolor);
     }
-    if (S[SP].pencolor == '\0')
+    if (*S[SP].pencolor == '\0')
 	return;
     fprintf(Output_file, Newpath_Moveto, A[0].x, A[0].y);
     for (j = 1; j < n; j++)
@@ -615,15 +615,15 @@ static void ps_ellipse(point p, int rx, int ry, int filled)
 {
     if (S[SP].invis)
 	return;
-    if (filled && S[SP].fillcolor) {
+    if (filled && *S[SP].fillcolor) {
 	ps_set_color(S[SP].fillcolor);
 	fprintf(Output_file, "%d %d %d %d ellipse_path\n", p.x, p.y, rx,
 		ry);
 	fprintf(Output_file, Fill);
-	if (S[SP].pencolor)
+	if (*S[SP].pencolor)
 	    ps_set_color(S[SP].pencolor);
     }
-    if (S[SP].pencolor == '\0')
+    if (*S[SP].pencolor == '\0')
 	return;
     if (!filled || (filled && strcmp(S[SP].fillcolor, S[SP].pencolor))) {
 	fprintf(Output_file, "%d %d %d %d ellipse_path\n", p.x, p.y, rx,
@@ -638,7 +638,7 @@ static void ps_polyline(point * A, int n)
 
     if (S[SP].invis)
 	return;
-    if (S[SP].pencolor == '\0')
+    if (*S[SP].pencolor == '\0')
 	return;
     fprintf(Output_file, Newpath_Moveto, A[0].x, A[0].y);
     for (j = 1; j < n; j++)
