@@ -1,4 +1,4 @@
-/* $Id: routespl.c,v 1.2 2004/12/11 19:26:05 ellson Exp $ $Revision: 1.2 $ */
+/* $Id: routespl.c,v 1.4 2005/04/05 20:32:49 ellson Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -174,7 +174,14 @@ point *routesplines(path * pp, int *npoints)
 		    polypoints[pi].x = boxes[bi].UR.x;
 		    polypoints[pi++].y = boxes[bi].UR.y;
 		}
-	    } else {
+	    }
+	    else if (prev == 0) { /* single box */
+		polypoints[pi].x = boxes[bi].LL.x;
+		polypoints[pi++].y = boxes[bi].UR.y;
+		polypoints[pi].x = boxes[bi].LL.x;
+		polypoints[pi++].y = boxes[bi].LL.y;
+	    } 
+	    else {
 		if (!(prev == -1 && next == -1))
 		    abort();
 	    }
@@ -186,7 +193,7 @@ point *routesplines(path * pp, int *npoints)
 	    if (bi > 0)
 		next = (boxes[bi - 1].LL.y > boxes[bi].LL.y) ? 1 : -1;
 	    if (prev != next) {
-		if (next == -1 || prev == 1) {
+		if (next == -1 || prev == 1 ) {
 		    polypoints[pi].x = boxes[bi].LL.x;
 		    polypoints[pi++].y = boxes[bi].UR.y;
 		    polypoints[pi].x = boxes[bi].LL.x;
@@ -197,7 +204,14 @@ point *routesplines(path * pp, int *npoints)
 		    polypoints[pi].x = boxes[bi].UR.x;
 		    polypoints[pi++].y = boxes[bi].UR.y;
 		}
-	    } else {
+	    } 
+	    else if (prev == 0) { /* single box */
+		polypoints[pi].x = boxes[bi].UR.x;
+		polypoints[pi++].y = boxes[bi].LL.y;
+		polypoints[pi].x = boxes[bi].UR.x;
+		polypoints[pi++].y = boxes[bi].UR.y;
+	    }
+	    else {
 		if (!(prev == -1 && next == -1)) {
 		    /* it went badly, e.g. degenerate box in boxlist */
 		    *npoints = 0;
