@@ -1,4 +1,4 @@
-/* $Id: shapes.c,v 1.125 2004/12/11 19:26:05 ellson Exp $ $Revision: 1.125 $ */
+/* $Id: shapes.c,v 1.127 2004/12/20 20:04:24 erg Exp $ $Revision: 1.127 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -956,22 +956,21 @@ static port poly_port(node_t * n, char *portname, char *compass)
     port rv;
     box *bp;
 
-    if ((portname[0] == '\0') && (!compass || (*compass == '\0')))
+    if (portname[0] == '\0')
 	return Center;
 
-    if ((ND_label(n)->html) && *portname) {
+    if ((ND_label(n)->html)) {
 	if ((bp = html_port(n, portname))) {
-	    if (compassPort(n, bp, &rv, compass))
+	    if (compassPort(n, bp, &rv, compass)) {
 		agerr(AGWARN,
 		      "node %s, port %s, unrecognized compass point '%s' - ignored\n",
 		      n->name, portname, compass);
-	} else {
-	    agerr(AGWARN, "node %s, unrecognized port '%s' - ignored\n",
-		  n->name, portname);
-	    return Center;
+	    }
+	} else if (compassPort(n, NULL, &rv, portname)) {
+	    unrecognized(n, portname);
 	}
-    } else if (compassPort(n, NULL, &rv, compass)) {
-	unrecognized(n, compass);
+    } else if (compassPort(n, NULL, &rv, portname)) {
+	unrecognized(n, portname);
     }
 
     return rv;
@@ -1475,19 +1474,14 @@ static port record_port(node_t * n, char *portname, char *compass)
     field_t *subf;
     port rv;
 
-    if ((portname[0] == '\0') && (!compass || (*compass == '\0')))
+    if (portname[0] == '\0')
 	return Center;
     f = (field_t *) ND_shape_info(n);
-    if (*portname) {
-	if ((subf = map_rec_port(f, portname))) {
-	    if (compassPort(n, &subf->b, &rv, compass))
-		agerr(AGWARN,
-		      "node %s, port %s, unrecognized compass point '%s' - ignored\n",
-		      n->name, portname, compass);
-	} else {
-	    agerr(AGWARN, "node %s, unrecognized port '%s',  - ignored\n",
-		  n->name, portname);
-	    return Center;
+    if ((subf = map_rec_port(f, portname))) {
+	if (compassPort(n, &subf->b, &rv, compass)) {
+	    agerr(AGWARN,
+	      "node %s, port %s, unrecognized compass point '%s' - ignored\n",
+	      n->name, portname, compass);
 	}
     } else if (compassPort(n, &f->b, &rv, portname)) {
 	unrecognized(n, portname);
