@@ -1,4 +1,4 @@
-/* $Id: types.h,v 1.79 2004/12/19 01:51:57 erg Exp $ $Revision: 1.79 $ */
+/* $Id: types.h,v 1.80 2005/04/05 20:32:49 ellson Exp $ $Revision: 1.80 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -67,6 +67,7 @@ extern "C" {
 	boolean	constrained;    /* if true, constraints such as theta are set */
 	boolean clip;           /* if true, clip end to node/port shape */
 	unsigned char order;	/* for mincross */
+	unsigned char side;     /* if port is on perimeter of node */
     } port;
 
     typedef struct {
@@ -532,6 +533,7 @@ extern "C" {
 	port tail_port, head_port;	/* might be used someday */
 	textlabel_t *label, *head_label, *tail_label;
 	char edge_type;
+	char adjacent;          /* true for flat edge with adjacent nodes */
 	char label_ontop;
 	edge_t *to_orig;	/* for dot's shapes.c    */
 	void *alg;
@@ -559,6 +561,7 @@ extern "C" {
 #define ED_cutvalue(e) (e)->u.cutvalue
 #define ED_dist(e) (e)->u.dist
 #define ED_edge_type(e) (e)->u.edge_type
+#define ED_adjacent(e) (e)->u.adjacent
 #define ED_factor(e) (e)->u.factor
 #define ED_head_label(e) (e)->u.head_label
 #define ED_head_port(e) (e)->u.head_port
