@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.76 2004/12/19 01:51:03 erg Exp $ $Revision: 1.76 $ */
+/* $Id: utils.c,v 1.77 2005/03/26 17:18:54 ellson Exp $ $Revision: 1.77 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -472,9 +472,11 @@ char *safefile(char *filename)
 	    return NULL;
 	}
 
-	/* allocate a buffer that we are sure is big enough */
+	/* allocate a buffer that we are sure is big enough
+	 * +1 for null character.
+	 */
 	safefilename = realloc(safefilename,
-			       (strlen(Gvfilepath) + strlen(filename)));
+			       (strlen(Gvfilepath) + strlen(filename) + 1));
 
 	strcpy(safefilename, Gvfilepath);
 	str = filename;
