@@ -1,4 +1,4 @@
-/* $Id: heap.c,v 1.11 2004/12/11 19:26:07 ellson Exp $ $Revision: 1.11 $ */
+/* $Id: heap.c,v 1.12 2005/04/05 18:10:11 ellson Exp $ $Revision: 1.12 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -31,12 +31,15 @@ static int PQmin;
 static int PQbucket(Halfedge * he)
 {
     int bucket;
+    double b;
 
-    bucket = (he->ystar - ymin) / deltay * PQhashsize;
-    if (bucket < 0)
+    b = (he->ystar - ymin) / deltay * PQhashsize;
+    if (b < 0)
 	bucket = 0;
-    if (bucket >= PQhashsize)
+    else if (b >= PQhashsize)
 	bucket = PQhashsize - 1;
+    else
+	bucket = b;
     if (bucket < PQmin)
 	PQmin = bucket;
     return (bucket);
@@ -77,13 +80,13 @@ void PQdelete(Halfedge * he)
 }
 
 
-int PQempty()
+int PQempty(void)
 {
     return (PQcount == 0);
 }
 
 
-Point PQ_min()
+Point PQ_min(void)
 {
     Point answer;
 
@@ -95,7 +98,7 @@ Point PQ_min()
     return (answer);
 }
 
-Halfedge *PQextractmin()
+Halfedge *PQextractmin(void)
 {
     Halfedge *curr;
 
@@ -105,13 +108,13 @@ Halfedge *PQextractmin()
     return (curr);
 }
 
-void PQcleanup()
+void PQcleanup(void)
 {
     free(PQhash);
     PQhash = NULL;
 }
 
-void PQinitialize()
+void PQinitialize(void)
 {
     int i;
 
@@ -132,7 +135,7 @@ static void PQdumphe(Halfedge * p)
 	   p->ystar);
 }
 
-void PQdump()
+void PQdump(void)
 {
     int i;
     Halfedge *p;
