@@ -1,4 +1,4 @@
-/* $Id: neatosplines.c,v 1.24 2004/12/11 19:26:08 ellson Exp $ $Revision: 1.24 $ */
+/* $Id: neatosplines.c,v 1.27 2005/04/05 21:53:29 ellson Exp $ $Revision: 1.27 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -124,52 +124,67 @@ static void endPoints(splines * spl, point * p, point * q)
 }
 
 #define LEFTOF(a,b,c) (((a.y - b.y)*(c.x - b.x) - (c.y - b.y)*(a.x - b.x)) > 0)
-#define MAXLABELWD  (POINTS_PER_INCH/4.0)
+#define MAXLABELWD  (POINTS_PER_INCH/2.0)
 
 /* addEdgeLabels:
- * p and q are the port points of the tail and head node.
+ * rp and rq are the port points of the tail and head node.
  * Adds label, headlabel and taillabel.
  * The use of 2 and 4 in computing ld.x and ld.y are fudge factors, to
  * introduce a bit of spacing.
  * Updates bounding box.
+ * We try to use the actual endpoints of the spline, as they may differ
+ * significantly from rp and rq, but if the spline is degenerate (e.g.,
+ * the nodes overlap), we use rp and rq.
  */
-static void addEdgeLabels(edge_t * e, point p, point q)
+static void addEdgeLabels(edge_t * e, point rp, point rq)
 {
+    point p, q;
     point d;			/* midpoint of segment p-q */
     point ld;
     point sp;
     point del;
-    double ht, wd;
+    pointf spf;
+    double f, ht, wd, dist2;
     int leftOf;
 
-    endPoints(ED_spl(e), &p, &q);
     if (ED_label(e) && !ED_label(e)->set) {
+	endPoints(ED_spl(e), &p, &q);
+	if ((p.x == q.x) && (p.y == q.y)) { /* degenerate spline */
+	    p = rp;
+	    q = rq;
+	}
 	d.x = (q.x + p.x) / 2;
 	d.y = (p.y + q.y) / 2;
 	del.x = q.x - p.x;
 	del.y = q.y - p.y;
+	dist2 = del.x*del.x + del.y*del.y;
+	ht = (ED_label(e)->dimen.y + 2)/2.0;
 	sp = dotneato_closest(ED_spl(e), d);
-	ht = ED_label(e)->dimen.y;
-	wd = ED_label(e)->dimen.x;
-	leftOf = LEFTOF(p, q, sp);
-	if (fabs(del.x) < fabs(del.y)) {	/* vertical edge */
-	    ld.y = 0;
-	    assert(del.y);
-	    ld.x = fabs((ht * del.x) / (2.0 * del.y)) + (4 + wd) / 2.0;
-	    if ((leftOf && (del.y > 0)) || (!leftOf && (del.y < 0)))
-		ld.x *= -1;
-	} else {		/* horizontal edge */
+	spf.x = sp.x;
+	spf.y = sp.y;
+	if (dist2) {
+	    wd = (MIN(ED_label(e)->dimen.x + 2, MAXLABELWD))/2.0;
+	    leftOf = LEFTOF(p, q, sp);
+	    if ((leftOf && (del.y >= 0)) || (!leftOf && (del.y < 0))) {
+		if (del.x*del.y >= 0)
+		    ht *= -1;
+	    }
+	    else {
+		wd *= -1;
+		if (del.x*del.y < 0)
+		    ht *= -1;
+	    }
+	    f = (del.y*wd - del.x*ht)/dist2;
+	    ld.x = -f*del.y;
+	    ld.y = f*del.x;
+	}
+	else {    /* end points the same */
 	    ld.x = 0;
-	    assert(del.x);
-	    /* prevent label from moving too far */
-	    wd = MIN(wd, MAXLABELWD);
-	    ld.y = fabs((wd * del.y) / (2.0 * del.x)) + (2 + ht) / 2.0;
-	    if ((!leftOf && (del.x > 0)) || (leftOf && (del.x < 0)))
-		ld.y *= -1;
+	    ld.y = -ht;
 	}
 
-	ED_label(e)->p.x = sp.x + ld.x;
-	ED_label(e)->p.y = sp.y + ld.y;
+	ED_label(e)->p.x = spf.x + ld.x;
+	ED_label(e)->p.y = spf.y + ld.y;
 	ED_label(e)->set = TRUE;
 	updateBB(e->tail->graph, ED_label(e));
     }
@@ -353,15 +368,24 @@ static void makeStraightEdge(graph_t * g, edge_t * e)
     e0 = e;
     perp.x = dumb[0].y - dumb[3].y;
     perp.y = dumb[3].x - dumb[0].x;
-    l_perp = sqrt(perp.x * perp.x + perp.y * perp.y);
-    xstep = GD_nodesep(g);
-    dx = xstep * (e_cnt - 1) / 2;
-    dumb[1].x = dumb[0].x + (dx * perp.x) / l_perp;
-    dumb[1].y = dumb[0].y + (dx * perp.y) / l_perp;
-    dumb[2].x = dumb[3].x + (dx * perp.x) / l_perp;
-    dumb[2].y = dumb[3].y + (dx * perp.y) / l_perp;
-    del.x = -xstep * perp.x / l_perp;
-    del.y = -xstep * perp.y / l_perp;
+    if ((perp.x == 0) && (perp.y == 0)) { 
+	/* degenerate case */
+	dumb[1] = dumb[0];
+	dumb[2] = dumb[3];
+	del.x = 0;
+	del.y = 0;
+    }
+    else {
+	l_perp = sqrt(perp.x * perp.x + perp.y * perp.y);
+	xstep = GD_nodesep(g);
+	dx = xstep * (e_cnt - 1) / 2;
+	dumb[1].x = dumb[0].x + (dx * perp.x) / l_perp;
+	dumb[1].y = dumb[0].y + (dx * perp.y) / l_perp;
+	dumb[2].x = dumb[3].x + (dx * perp.x) / l_perp;
+	dumb[2].y = dumb[3].y + (dx * perp.y) / l_perp;
+	del.x = -xstep * perp.x / l_perp;
+	del.y = -xstep * perp.y / l_perp;
+    }
 
     for (i = 0; i < e_cnt; i++) {
 	if (e0->head == head) {
@@ -612,7 +636,8 @@ static int _spline_edges(graph_t * g, double SEP, int splines)
 			      add_points(ND_coord_i(n), ED_tail_port(e).p),
 			      add_points(ND_coord_i(head),
 					 ED_head_port(e).p));
-	    } else if ((n == head) && ED_count(e)) {	/* self arc */
+	    } else if (n == head) {    /* self arc */
+		if (ED_count(e) == 0) continue;   /* only do representative */
 		if (!P) {
 		    P = NEW(path);
 		    P->boxes = N_NEW(agnnodes(g) + 20 * 2 * 9, box);
