@@ -1,14 +1,14 @@
-/*   Copyright (c) AT&T Corp.  All rights reserved.
-   
-This software may only be used by you under license from 
-AT&T Corp. ("AT&T").  A copy of AT&T's Source Code Agreement 
-is available at AT&T's Internet website having the URL 
-
-http://www.research.att.com/sw/tools/graphviz/license/
-
-If you received this software without first entering into a license 
-with AT&T, you have an infringing copy of this software and cannot 
-use it without violating AT&T's intellectual property rights. */
+/* $Id: UVCross.cpp,v 1.6 2005/04/05 11:32:55 ellson Exp $ $Revision: 1.6 $ */
+/* vim:set shiftwidth=4 ts=8: */
+/*
+ This software is part of the graphviz package
+ Copyright (c) 1995-2004 AT&T Corp.
+ Licensed under the Common Public License, Version 1.0 (the "License")
+ Any use, reproduction or distribution of this software constitutes
+ acceptance of the License.  A copy of the License is available at:
+     http://www.research.att.com/sw/license/cpl-1.0.html
+ (with md5 checksum 201a9e4ba08a96f5d9677315d8ce1463)
+*/
 
 #include "dynadag/DynaDAG.h"
 
