@@ -1,19 +1,14 @@
-/* $Id: gscmds.h,v 1.7 2004/12/11 19:26:08 ellson Exp $ $Revision: 1.7 $ */
+/* $Id: gscmds.h,v 1.8 2005/04/05 12:02:55 ellson Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
-
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
-
+/*
+ This software is part of the graphviz package
+ Copyright (c) 1995-2004 AT&T Corp.
+ Licensed under the Common Public License, Version 1.0 (the "License")
+ Any use, reproduction or distribution of this software constitutes
+ acceptance of the License.  A copy of the License is available at:
+     http://www.research.att.com/sw/license/cpl-1.0.html
+ (with md5 checksum 201a9e4ba08a96f5d9677315d8ce1463)
+*/
 
 #include <assert.h>
 #include <stdio.h>
@@ -35,12 +30,12 @@ void gs_define_search();
 void gs_define_input();
 
 void gs_mod_view(char *id);
-void gs_ins_node(char *view, char *id);
-void gs_mod_node(char *view, char *id);
-void gs_del_node(char *view, char *id);
-void gs_ins_edge(char *view, char *id, char *tail, char *head);
-void gs_mod_edge(char *view, char *id);
-void gs_del_edge(char *view, char *id);
+void gs_ins_node(char *view,char *id);
+void gs_mod_node(char *view,char *id);
+void gs_del_node(char *view,char *id);
+void gs_ins_edge(char *view,char *id, char *tail, char *head);
+void gs_mod_edge(char *view,char *id);
+void gs_del_edge(char *view,char *id);
 
 void gs_view_obj(char *vid, char *objid);
 void gs_unview_obj(char *vid, char *objid);
