@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875c.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -123,7 +123,7 @@ typedef union YYSTYPE {
 			int				i;
 			char			*str;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
+/* Line 190 of yacc.c.  */
 #line 128 "y.tab.c"
 # define gs_yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -135,7 +135,7 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
+/* Line 213 of yacc.c.  */
 #line 140 "y.tab.c"
 
 #if ! defined (gs_yyoverflow) || YYERROR_VERBOSE
@@ -151,14 +151,10 @@ typedef union YYSTYPE {
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -184,7 +180,7 @@ typedef union YYSTYPE {
 /* A type that is properly aligned for any stack member.  */
 union gs_yyalloc
 {
-  short gs_yyss;
+  short int gs_yyss;
   YYSTYPE gs_yyvs;
   };
 
@@ -194,7 +190,7 @@ union gs_yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
@@ -236,7 +232,7 @@ union gs_yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char gs_yysigned_char;
 #else
-   typedef short gs_yysigned_char;
+   typedef short int gs_yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -358,7 +354,7 @@ static const char *const gs_yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short gs_yytoknum[] =
+static const unsigned short int gs_yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
@@ -529,20 +525,53 @@ do								\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `gs_yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -565,19 +594,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (gs_yydebug)					\
-    gs_yysymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (gs_yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       gs_yysymprint (stderr, 					\
-                  Token, Value);	\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -589,12 +612,12 @@ do {								\
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-gs_yy_stack_print (short *bottom, short *top)
+gs_yy_stack_print (short int *bottom, short int *top)
 #else
 static void
 gs_yy_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -644,8 +667,7 @@ do {					\
 int gs_yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -663,10 +685,6 @@ int gs_yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -748,15 +766,15 @@ gs_yysymprint (gs_yyoutput, gs_yytype, gs_yyvaluep)
   (void) gs_yyvaluep;
 
   if (gs_yytype < YYNTOKENS)
-    {
-      YYFPRINTF (gs_yyoutput, "token %s (", gs_yytname[gs_yytype]);
-# ifdef YYPRINT
-      YYPRINT (gs_yyoutput, gs_yytoknum[gs_yytype], *gs_yyvaluep);
-# endif
-    }
+    YYFPRINTF (gs_yyoutput, "token %s (", gs_yytname[gs_yytype]);
   else
     YYFPRINTF (gs_yyoutput, "nterm %s (", gs_yytname[gs_yytype]);
 
+
+# ifdef YYPRINT
+  if (gs_yytype < YYNTOKENS)
+    YYPRINT (gs_yyoutput, gs_yytoknum[gs_yytype], *gs_yyvaluep);
+# endif
   switch (gs_yytype)
     {
       default:
@@ -772,10 +790,11 @@ gs_yysymprint (gs_yyoutput, gs_yytype, gs_yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-gs_yydestruct (int gs_yytype, YYSTYPE *gs_yyvaluep)
+gs_yydestruct (const char *gs_yymsg, int gs_yytype, YYSTYPE *gs_yyvaluep)
 #else
 static void
-gs_yydestruct (gs_yytype, gs_yyvaluep)
+gs_yydestruct (gs_yymsg, gs_yytype, gs_yyvaluep)
+    const char *gs_yymsg;
     int gs_yytype;
     YYSTYPE *gs_yyvaluep;
 #endif
@@ -783,6 +802,10 @@ gs_yydestruct (gs_yytype, gs_yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) gs_yyvaluep;
 
+  if (!gs_yymsg)
+    gs_yymsg = "Deleting";
+  YY_SYMBOL_PRINT (gs_yymsg, gs_yytype, gs_yyvaluep, gs_yylocationp);
+
   switch (gs_yytype)
     {
 
@@ -810,10 +833,10 @@ int gs_yyparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int gs_yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE gs_yylval;
 
 /* Number of syntax errors so far.  */
@@ -849,7 +872,7 @@ gs_yyparse ()
   int gs_yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int gs_yyerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int gs_yytoken = 0;
 
   /* Three stacks and their tools:
@@ -861,9 +884,9 @@ gs_yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	gs_yyssa[YYINITDEPTH];
-  short *gs_yyss = gs_yyssa;
-  register short *gs_yyssp;
+  short int gs_yyssa[YYINITDEPTH];
+  short int *gs_yyss = gs_yyssa;
+  register short int *gs_yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE gs_yyvsa[YYINITDEPTH];
@@ -900,6 +923,9 @@ gs_yyparse ()
   gs_yyssp = gs_yyss;
   gs_yyvsp = gs_yyvs;
 
+
+  gs_yyvsp[0] = gs_yylval;
+
   goto gs_yysetstate;
 
 /*------------------------------------------------------------.
@@ -925,7 +951,7 @@ gs_yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *gs_yyvs1 = gs_yyvs;
-	short *gs_yyss1 = gs_yyss;
+	short int *gs_yyss1 = gs_yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -953,7 +979,7 @@ gs_yyparse ()
 	gs_yystacksize = YYMAXDEPTH;
 
       {
-	short *gs_yyss1 = gs_yyss;
+	short int *gs_yyss1 = gs_yyss;
 	union gs_yyalloc *gs_yyptr =
 	  (union gs_yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (gs_yystacksize));
 	if (! gs_yyptr)
@@ -989,18 +1015,18 @@ gs_yyparse ()
 gs_yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* gs_yyresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   gs_yyn = gs_yypact[gs_yystate];
   if (gs_yyn == YYPACT_NINF)
     goto gs_yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (gs_yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1015,7 +1041,7 @@ gs_yybackup:
   else
     {
       gs_yytoken = YYTRANSLATE (gs_yychar);
-      YYDSYMPRINTF ("Next token is", gs_yytoken, &gs_yylval, &gs_yylloc);
+      YY_SYMBOL_PRINT ("Next token is", gs_yytoken, &gs_yylval, &gs_yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1035,8 +1061,8 @@ gs_yybackup:
   if (gs_yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", gs_yytname[gs_yytoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", gs_yytoken, &gs_yylval, &gs_yylloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (gs_yychar != YYEOF)
@@ -1097,32 +1123,32 @@ gs_yyreduce:
 
   case 24:
 #line 45 "gsgram.ypp"
-    {gs_open_view(gs_yyvsp[-1].str);}
+    {gs_open_view((gs_yyvsp[-1].str));}
     break;
 
   case 25:
 #line 48 "gsgram.ypp"
-    {gs_close_view(gs_yyvsp[0].str);}
+    {gs_close_view((gs_yyvsp[0].str));}
     break;
 
   case 26:
 #line 51 "gsgram.ypp"
-    {gs_mod_view(gs_yyvsp[-1].str);}
+    {gs_mod_view((gs_yyvsp[-1].str));}
     break;
 
   case 27:
 #line 54 "gsgram.ypp"
-    {gs_lock(gs_yyvsp[0].str);}
+    {gs_lock((gs_yyvsp[0].str));}
     break;
 
   case 28:
 #line 57 "gsgram.ypp"
-    {gs_unlock(gs_yyvsp[0].str);}
+    {gs_unlock((gs_yyvsp[0].str));}
     break;
 
   case 29:
 #line 60 "gsgram.ypp"
-    {gs_segue(gs_yyvsp[0].str);}
+    {gs_segue((gs_yyvsp[0].str));}
     break;
 
   case 30:
@@ -1142,32 +1168,32 @@ gs_yyreduce:
 
   case 33:
 #line 72 "gsgram.ypp"
-    {gs_ins_node(gs_yyvsp[-3].str,gs_yyvsp[-1].str);}
+    {gs_ins_node((gs_yyvsp[-3].str),(gs_yyvsp[-1].str));}
     break;
 
   case 34:
 #line 75 "gsgram.ypp"
-    {gs_mod_node(gs_yyvsp[-3].str,gs_yyvsp[-1].str);}
+    {gs_mod_node((gs_yyvsp[-3].str),(gs_yyvsp[-1].str));}
     break;
 
   case 35:
 #line 78 "gsgram.ypp"
-    {gs_del_node(gs_yyvsp[-2].str,gs_yyvsp[0].str);}
+    {gs_del_node((gs_yyvsp[-2].str),(gs_yyvsp[0].str));}
     break;
 
   case 36:
 #line 81 "gsgram.ypp"
-    {gs_ins_edge(gs_yyvsp[-5].str,gs_yyvsp[-3].str,gs_yyvsp[-2].str,gs_yyvsp[-1].str);}
+    {gs_ins_edge((gs_yyvsp[-5].str),(gs_yyvsp[-3].str),(gs_yyvsp[-2].str),(gs_yyvsp[-1].str));}
     break;
 
   case 37:
 #line 84 "gsgram.ypp"
-    {gs_mod_edge(gs_yyvsp[-3].str,gs_yyvsp[-1].str);}
+    {gs_mod_edge((gs_yyvsp[-3].str),(gs_yyvsp[-1].str));}
     break;
 
   case 38:
 #line 87 "gsgram.ypp"
-    {gs_del_edge(gs_yyvsp[-2].str,gs_yyvsp[0].str);}
+    {gs_del_edge((gs_yyvsp[-2].str),(gs_yyvsp[0].str));}
     break;
 
   case 39:
@@ -1182,19 +1208,19 @@ gs_yyreduce:
 
   case 46:
 #line 102 "gsgram.ypp"
-    {gs_append_attr(gs_yyvsp[-2].str,gs_yyvsp[0].str);}
+    {gs_append_attr((gs_yyvsp[-2].str),(gs_yyvsp[0].str));}
     break;
 
   case 50:
 #line 107 "gsgram.ypp"
-    {gs_yyval.str = gs_yyvsp[0].str; }
+    {(gs_yyval.str) = (gs_yyvsp[0].str); }
     break;
 
 
     }
 
-/* Line 1000 of yacc.c.  */
-#line 1198 "y.tab.c"
+/* Line 1037 of yacc.c.  */
+#line 1224 "y.tab.c"
 
   gs_yyvsp -= gs_yylen;
   gs_yyssp -= gs_yylen;
@@ -1294,7 +1320,7 @@ gs_yyerrlab:
 
   if (gs_yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (gs_yychar <= YYEOF)
@@ -1304,23 +1330,22 @@ gs_yyerrlab:
 	  if (gs_yychar == YYEOF)
 	     for (;;)
 	       {
+
 		 YYPOPSTACK;
 		 if (gs_yyssp == gs_yyss)
 		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", gs_yystos[*gs_yyssp], gs_yyvsp, gs_yylsp);
-		 gs_yydestruct (gs_yystos[*gs_yyssp], gs_yyvsp);
+		 gs_yydestruct ("Error: popping",
+                             gs_yystos[*gs_yyssp], gs_yyvsp);
 	       }
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", gs_yytoken, &gs_yylval, &gs_yylloc);
-	  gs_yydestruct (gs_yytoken, &gs_yylval);
+	  gs_yydestruct ("Error: discarding", gs_yytoken, &gs_yylval);
 	  gs_yychar = YYEMPTY;
-
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto gs_yyerrlab1;
 
@@ -1337,7 +1362,7 @@ gs_yyerrorlab:
      goto gs_yyerrorlab;
 #endif
 
-  gs_yyvsp -= gs_yylen;
+gs_yyvsp -= gs_yylen;
   gs_yyssp -= gs_yylen;
   gs_yystate = *gs_yyssp;
   goto gs_yyerrlab1;
@@ -1367,8 +1392,8 @@ gs_yyerrlab1:
       if (gs_yyssp == gs_yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", gs_yystos[*gs_yyssp], gs_yyvsp, gs_yylsp);
-      gs_yydestruct (gs_yystos[gs_yystate], gs_yyvsp);
+
+      gs_yydestruct ("Error: popping", gs_yystos[gs_yystate], gs_yyvsp);
       YYPOPSTACK;
       gs_yystate = *gs_yyssp;
       YY_STACK_PRINT (gs_yyss, gs_yyssp);
@@ -1377,11 +1402,12 @@ gs_yyerrlab1:
   if (gs_yyn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++gs_yyvsp = gs_yylval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", gs_yystos[gs_yyn], gs_yyvsp, gs_yylsp);
+
   gs_yystate = gs_yyn;
   goto gs_yynewstate;
 
@@ -1397,6 +1423,9 @@ gs_yyacceptlab:
 | gs_yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 gs_yyabortlab:
+  gs_yydestruct ("Error: discarding lookahead",
+              gs_yytoken, &gs_yylval);
+  gs_yychar = YYEMPTY;
   gs_yyresult = 1;
   goto gs_yyreturn;
 
