@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875c.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -117,7 +117,7 @@ typedef union YYSTYPE {
 			int				i;
 			char			*str;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
+/* Line 190 of yacc.c.  */
 #line 122 "y.tab.c"
 # define incr_yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -129,7 +129,7 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
+/* Line 213 of yacc.c.  */
 #line 134 "y.tab.c"
 
 #if ! defined (incr_yyoverflow) || YYERROR_VERBOSE
@@ -145,14 +145,10 @@ typedef union YYSTYPE {
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -178,7 +174,7 @@ typedef union YYSTYPE {
 /* A type that is properly aligned for any stack member.  */
 union incr_yyalloc
 {
-  short incr_yyss;
+  short int incr_yyss;
   YYSTYPE incr_yyvs;
   };
 
@@ -188,7 +184,7 @@ union incr_yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
@@ -230,7 +226,7 @@ union incr_yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char incr_yysigned_char;
 #else
-   typedef short incr_yysigned_char;
+   typedef short int incr_yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -349,7 +345,7 @@ static const char *const incr_yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short incr_yytoknum[] =
+static const unsigned short int incr_yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,    10,
@@ -518,20 +514,53 @@ do								\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `incr_yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -554,19 +583,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (incr_yydebug)					\
-    incr_yysymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (incr_yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       incr_yysymprint (stderr, 					\
-                  Token, Value);	\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -578,12 +601,12 @@ do {								\
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-incr_yy_stack_print (short *bottom, short *top)
+incr_yy_stack_print (short int *bottom, short int *top)
 #else
 static void
 incr_yy_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -633,8 +656,7 @@ do {					\
 int incr_yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -652,10 +674,6 @@ int incr_yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -737,15 +755,15 @@ incr_yysymprint (incr_yyoutput, incr_yytype, incr_yyvaluep)
   (void) incr_yyvaluep;
 
   if (incr_yytype < YYNTOKENS)
-    {
-      YYFPRINTF (incr_yyoutput, "token %s (", incr_yytname[incr_yytype]);
-# ifdef YYPRINT
-      YYPRINT (incr_yyoutput, incr_yytoknum[incr_yytype], *incr_yyvaluep);
-# endif
-    }
+    YYFPRINTF (incr_yyoutput, "token %s (", incr_yytname[incr_yytype]);
   else
     YYFPRINTF (incr_yyoutput, "nterm %s (", incr_yytname[incr_yytype]);
 
+
+# ifdef YYPRINT
+  if (incr_yytype < YYNTOKENS)
+    YYPRINT (incr_yyoutput, incr_yytoknum[incr_yytype], *incr_yyvaluep);
+# endif
   switch (incr_yytype)
     {
       default:
@@ -761,10 +779,11 @@ incr_yysymprint (incr_yyoutput, incr_yytype, incr_yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-incr_yydestruct (int incr_yytype, YYSTYPE *incr_yyvaluep)
+incr_yydestruct (const char *incr_yymsg, int incr_yytype, YYSTYPE *incr_yyvaluep)
 #else
 static void
-incr_yydestruct (incr_yytype, incr_yyvaluep)
+incr_yydestruct (incr_yymsg, incr_yytype, incr_yyvaluep)
+    const char *incr_yymsg;
     int incr_yytype;
     YYSTYPE *incr_yyvaluep;
 #endif
@@ -772,6 +791,10 @@ incr_yydestruct (incr_yytype, incr_yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) incr_yyvaluep;
 
+  if (!incr_yymsg)
+    incr_yymsg = "Deleting";
+  YY_SYMBOL_PRINT (incr_yymsg, incr_yytype, incr_yyvaluep, incr_yylocationp);
+
   switch (incr_yytype)
     {
 
@@ -799,10 +822,10 @@ int incr_yyparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int incr_yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE incr_yylval;
 
 /* Number of syntax errors so far.  */
@@ -838,7 +861,7 @@ incr_yyparse ()
   int incr_yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int incr_yyerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int incr_yytoken = 0;
 
   /* Three stacks and their tools:
@@ -850,9 +873,9 @@ incr_yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	incr_yyssa[YYINITDEPTH];
-  short *incr_yyss = incr_yyssa;
-  register short *incr_yyssp;
+  short int incr_yyssa[YYINITDEPTH];
+  short int *incr_yyss = incr_yyssa;
+  register short int *incr_yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE incr_yyvsa[YYINITDEPTH];
@@ -889,6 +912,9 @@ incr_yyparse ()
   incr_yyssp = incr_yyss;
   incr_yyvsp = incr_yyvs;
 
+
+  incr_yyvsp[0] = incr_yylval;
+
   goto incr_yysetstate;
 
 /*------------------------------------------------------------.
@@ -914,7 +940,7 @@ incr_yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *incr_yyvs1 = incr_yyvs;
-	short *incr_yyss1 = incr_yyss;
+	short int *incr_yyss1 = incr_yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -942,7 +968,7 @@ incr_yyparse ()
 	incr_yystacksize = YYMAXDEPTH;
 
       {
-	short *incr_yyss1 = incr_yyss;
+	short int *incr_yyss1 = incr_yyss;
 	union incr_yyalloc *incr_yyptr =
 	  (union incr_yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (incr_yystacksize));
 	if (! incr_yyptr)
@@ -978,18 +1004,18 @@ incr_yyparse ()
 incr_yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* incr_yyresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   incr_yyn = incr_yypact[incr_yystate];
   if (incr_yyn == YYPACT_NINF)
     goto incr_yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (incr_yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1004,7 +1030,7 @@ incr_yybackup:
   else
     {
       incr_yytoken = YYTRANSLATE (incr_yychar);
-      YYDSYMPRINTF ("Next token is", incr_yytoken, &incr_yylval, &incr_yylloc);
+      YY_SYMBOL_PRINT ("Next token is", incr_yytoken, &incr_yylval, &incr_yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1024,8 +1050,8 @@ incr_yybackup:
   if (incr_yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", incr_yytname[incr_yytoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", incr_yytoken, &incr_yylval, &incr_yylloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (incr_yychar != YYEOF)
@@ -1081,7 +1107,7 @@ incr_yyreduce:
 
   case 21:
 #line 42 "incrgram.ypp"
-    {incr_message(incr_yyvsp[0].str);}
+    {incr_message((incr_yyvsp[0].str));}
     break;
 
   case 22:
@@ -1091,62 +1117,62 @@ incr_yyreduce:
 
   case 23:
 #line 48 "incrgram.ypp"
-    {incr_open_view(incr_yyvsp[-1].str);}
+    {incr_open_view((incr_yyvsp[-1].str));}
     break;
 
   case 24:
 #line 51 "incrgram.ypp"
-    {incr_close_view(incr_yyvsp[0].str);}
+    {incr_close_view((incr_yyvsp[0].str));}
     break;
 
   case 25:
 #line 54 "incrgram.ypp"
-    {incr_mod_view(incr_yyvsp[-1].str);}
+    {incr_mod_view((incr_yyvsp[-1].str));}
     break;
 
   case 26:
 #line 57 "incrgram.ypp"
-    {incr_lock(incr_yyvsp[0].str);}
+    {incr_lock((incr_yyvsp[0].str));}
     break;
 
   case 27:
 #line 60 "incrgram.ypp"
-    {incr_unlock(incr_yyvsp[0].str);}
+    {incr_unlock((incr_yyvsp[0].str));}
     break;
 
   case 28:
 #line 63 "incrgram.ypp"
-    {incr_segue(incr_yyvsp[0].str);}
+    {incr_segue((incr_yyvsp[0].str));}
     break;
 
   case 29:
 #line 66 "incrgram.ypp"
-    {incr_ins_node(incr_yyvsp[-3].str,incr_yyvsp[-1].str);}
+    {incr_ins_node((incr_yyvsp[-3].str),(incr_yyvsp[-1].str));}
     break;
 
   case 30:
 #line 69 "incrgram.ypp"
-    {incr_mod_node(incr_yyvsp[-3].str,incr_yyvsp[-1].str);}
+    {incr_mod_node((incr_yyvsp[-3].str),(incr_yyvsp[-1].str));}
     break;
 
   case 31:
 #line 72 "incrgram.ypp"
-    {incr_del_node(incr_yyvsp[-2].str,incr_yyvsp[0].str);}
+    {incr_del_node((incr_yyvsp[-2].str),(incr_yyvsp[0].str));}
     break;
 
   case 32:
 #line 75 "incrgram.ypp"
-    {incr_ins_edge(incr_yyvsp[-5].str,incr_yyvsp[-3].str,incr_yyvsp[-2].str,incr_yyvsp[-1].str);}
+    {incr_ins_edge((incr_yyvsp[-5].str),(incr_yyvsp[-3].str),(incr_yyvsp[-2].str),(incr_yyvsp[-1].str));}
     break;
 
   case 33:
 #line 78 "incrgram.ypp"
-    {incr_mod_edge(incr_yyvsp[-3].str,incr_yyvsp[-1].str);}
+    {incr_mod_edge((incr_yyvsp[-3].str),(incr_yyvsp[-1].str));}
     break;
 
   case 34:
 #line 81 "incrgram.ypp"
-    {incr_del_edge(incr_yyvsp[-2].str,incr_yyvsp[0].str);}
+    {incr_del_edge((incr_yyvsp[-2].str),(incr_yyvsp[0].str));}
     break;
 
   case 35:
@@ -1161,19 +1187,19 @@ incr_yyreduce:
 
   case 42:
 #line 96 "incrgram.ypp"
-    {incr_append_attr(incr_yyvsp[-2].str,incr_yyvsp[0].str);}
+    {incr_append_attr((incr_yyvsp[-2].str),(incr_yyvsp[0].str));}
     break;
 
   case 46:
 #line 101 "incrgram.ypp"
-    {incr_yyval.str = incr_yyvsp[0].str; }
+    {(incr_yyval.str) = (incr_yyvsp[0].str); }
     break;
 
 
     }
 
-/* Line 1000 of yacc.c.  */
-#line 1177 "y.tab.c"
+/* Line 1037 of yacc.c.  */
+#line 1203 "y.tab.c"
 
   incr_yyvsp -= incr_yylen;
   incr_yyssp -= incr_yylen;
@@ -1273,7 +1299,7 @@ incr_yyerrlab:
 
   if (incr_yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (incr_yychar <= YYEOF)
@@ -1283,23 +1309,22 @@ incr_yyerrlab:
 	  if (incr_yychar == YYEOF)
 	     for (;;)
 	       {
+
 		 YYPOPSTACK;
 		 if (incr_yyssp == incr_yyss)
 		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", incr_yystos[*incr_yyssp], incr_yyvsp, incr_yylsp);
-		 incr_yydestruct (incr_yystos[*incr_yyssp], incr_yyvsp);
+		 incr_yydestruct ("Error: popping",
+                             incr_yystos[*incr_yyssp], incr_yyvsp);
 	       }
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", incr_yytoken, &incr_yylval, &incr_yylloc);
-	  incr_yydestruct (incr_yytoken, &incr_yylval);
+	  incr_yydestruct ("Error: discarding", incr_yytoken, &incr_yylval);
 	  incr_yychar = YYEMPTY;
-
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto incr_yyerrlab1;
 
@@ -1316,7 +1341,7 @@ incr_yyerrorlab:
      goto incr_yyerrorlab;
 #endif
 
-  incr_yyvsp -= incr_yylen;
+incr_yyvsp -= incr_yylen;
   incr_yyssp -= incr_yylen;
   incr_yystate = *incr_yyssp;
   goto incr_yyerrlab1;
@@ -1346,8 +1371,8 @@ incr_yyerrlab1:
       if (incr_yyssp == incr_yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", incr_yystos[*incr_yyssp], incr_yyvsp, incr_yylsp);
-      incr_yydestruct (incr_yystos[incr_yystate], incr_yyvsp);
+
+      incr_yydestruct ("Error: popping", incr_yystos[incr_yystate], incr_yyvsp);
       YYPOPSTACK;
       incr_yystate = *incr_yyssp;
       YY_STACK_PRINT (incr_yyss, incr_yyssp);
@@ -1356,11 +1381,12 @@ incr_yyerrlab1:
   if (incr_yyn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++incr_yyvsp = incr_yylval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", incr_yystos[incr_yyn], incr_yyvsp, incr_yylsp);
+
   incr_yystate = incr_yyn;
   goto incr_yynewstate;
 
@@ -1376,6 +1402,9 @@ incr_yyacceptlab:
 | incr_yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 incr_yyabortlab:
+  incr_yydestruct ("Error: discarding lookahead",
+              incr_yytoken, &incr_yylval);
+  incr_yychar = YYEMPTY;
   incr_yyresult = 1;
   goto incr_yyreturn;
 
