@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875c.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@
 #include "dmalloc.h"
 #endif
 
-static char		*Port,*Subport;
+static char		*Port;
 static char		In_decl,In_edge_stmt;
 static int		Current_class,Agraph_type;
 static Agsym_t		*headsubsym;
@@ -121,7 +121,6 @@ static objport_t pop_gobj(void)
 	objport_t	rv;
 	rv.obj = pop_subg();
 	rv.port = NULL;
-	rv.subport = NULL;
 	return rv;
 }
 
@@ -202,18 +201,6 @@ static void mid_edgestmt(objport_t objp)
 	SP->last->link = NULL;
 }
 
-static Agsym_t*
-initEdgeSym (Agedge_t* e, char* name)
-{
-	 Agsym_t* ap;
-
-	ap = agfindattr(e,name);
-	if (ap == NULL)
-		ap = agedgeattr(AG.parsed_g,name,"");
-	ap->printed = FALSE;
-	return ap;
-}
-
 static void end_edgestmt(void)
 {
 	objstack_t	*old_SP;
@@ -221,14 +208,12 @@ static void end_edgestmt(void)
 	Agraph_t		*t_graph,*h_graph;
 	Agnode_t	*t_node,*h_node,*t_first,*h_first;
 	Agedge_t	*e;
-	char		*tport,*hport,*tsport,*hsport;
+	char		*tport,*hport;
 
 	for (tailptr = SP->list; tailptr->link; tailptr = tailptr->link) {
 		headptr = tailptr->link;
 		tport = tailptr->data.port;
 		hport = headptr->data.port;
-		tsport = tailptr->data.subport;
-		hsport = headptr->data.subport;
 		if (TAG_OF(tailptr->data.obj) == TAG_NODE) {
 			t_graph = NULL;
 			t_first = (Agnode_t*)(tailptr->data.obj);
@@ -254,31 +239,18 @@ static void end_edgestmt(void)
 				if (e) {
 					char	*tp = tport;
 					char 	*hp = hport;
-					char	*tsp = tsport;
-					char 	*hsp = hsport;
 					if ((e->tail != e->head) && (e->head == t_node)) {
 						/* could happen with an undirected edge */
 						char 	*temp;
 						temp = tp; tp = hp; hp = temp;
-						temp = tsp; tsp = hsp; hsp = temp;
 					}
 					if (tp && tp[0]) {
 						agxset(e,TAILX,tp);
 						agstrfree(tp); 
-						if (tsp && tsp[0]) {
-							if (!tailsubsym) tailsubsym = initEdgeSym (e,TAILSUB_ID);
-							agxset(e,tailsubsym->index,tsp);
-							agstrfree(tsp); 
-						}
 					}
 					if (hp && hp[0]) {
 						agxset(e,HEADX,hp);
 						agstrfree(hp); 
-						if (hsp && hsp[0]) {
-							if (!headsubsym) headsubsym = initEdgeSym (e,HEADSUB_ID);
-							agxset(e,headsubsym->index,hsp);
-							agstrfree(hsp); 
-						}
 					}
 				}
 			}
@@ -331,26 +303,6 @@ static void attr_set(char *name, char *value)
 				ap = agedgeattr(AG.parsed_g,name,defval);
             else if (ap->fixed && In_decl)
               return;
-			if (ap->index == HEADX) {
-				char* cp = strchr(value,':');
-				if (cp) {
-					*cp++ = '\0';
-					if (cp[0]) {
-						if (!headsubsym) headsubsym = initEdgeSym(E,HEADSUB_ID);
-						agxset(E,headsubsym->index,cp);
-					}
-				}
-			}
-			else if (ap->index == TAILX) {
-				char* cp = strchr(value,':');
-				if (cp) {
-					*cp++ = '\0';
-					if (cp[0]) {
-						if (!tailsubsym) tailsubsym = initEdgeSym(E,TAILSUB_ID);
-						agxset(E,tailsubsym->index,cp);
-					}
-				}
-			}
 			agxset(E,ap->index,value);
 			break;
 		case 0:		/* default */
@@ -384,6 +336,26 @@ concat (char* s1, char* s2)
   return s;
 }
 
+/* concat3:
+ */
+static char*
+concat3 (char* s1, char* s2, char*s3)
+{
+  char*  s;
+  char   buf[BUFSIZ];
+  char*  sym;
+  int    len = strlen(s1) + strlen(s2) + strlen(s3) + 1;
+
+  if (len <= BUFSIZ) sym = buf;
+  else sym = (char*)malloc(len);
+  strcpy(sym,s1);
+  strcat(sym,s2);
+  strcat(sym,s3);
+  s = agstrdup (sym);
+  if (sym != buf) free (sym);
+  return s;
+}
+
 
 
 /* Enabling traces.  */
@@ -400,15 +372,15 @@ concat (char* s1, char* s2)
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 324 "../graph/parser.y"
+#line 296 "../graph/parser.y"
 typedef union YYSTYPE {
 			int					i;
 			char				*str;
 			struct objport_t	obj;
 			struct Agnode_t		*n;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
-#line 412 "y.tab.c"
+/* Line 190 of yacc.c.  */
+#line 384 "y.tab.c"
 # define agstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -419,8 +391,8 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
-#line 424 "y.tab.c"
+/* Line 213 of yacc.c.  */
+#line 396 "y.tab.c"
 
 #if ! defined (agoverflow) || YYERROR_VERBOSE
 
@@ -435,14 +407,10 @@ typedef union YYSTYPE {
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -468,7 +436,7 @@ typedef union YYSTYPE {
 /* A type that is properly aligned for any stack member.  */
 union agalloc
 {
-  short agss;
+  short int agss;
   YYSTYPE agvs;
   };
 
@@ -478,7 +446,7 @@ union agalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
@@ -520,7 +488,7 @@ union agalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char agsigned_char;
 #else
-   typedef short agsigned_char;
+   typedef short int agsigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -614,15 +582,15 @@ static const agsigned_char agrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const unsigned short agrline[] =
+static const unsigned short int agrline[] =
 {
-       0,   342,   342,   341,   345,   352,   355,   355,   358,   360,
-     362,   364,   368,   370,   372,   376,   377,   380,   381,   384,
-     387,   388,   391,   394,   398,   399,   403,   404,   407,   408,
-     411,   412,   413,   416,   417,   418,   419,   422,   424,   428,
-     443,   446,   447,   448,   452,   451,   458,   460,   457,   465,
-     467,   464,   473,   475,   474,   477,   480,   479,   485,   486,
-     486,   487,   487,   488,   491,   501,   502,   505,   506
+       0,   314,   314,   313,   317,   324,   327,   327,   330,   332,
+     334,   336,   340,   342,   344,   348,   349,   352,   353,   356,
+     359,   360,   363,   366,   370,   371,   375,   376,   379,   380,
+     383,   384,   385,   388,   389,   390,   391,   394,   396,   400,
+     410,   413,   414,   415,   419,   418,   425,   427,   424,   432,
+     434,   431,   440,   442,   441,   444,   447,   446,   452,   453,
+     453,   454,   454,   455,   458,   468,   469,   472,   473
 };
 #endif
 
@@ -646,7 +614,7 @@ static const char *const agtname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short agtoknum[] =
+static const unsigned short int agtoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   123,   125,    44,    91,    93,    61,    59,    58,
@@ -825,20 +793,53 @@ do								\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `aglex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -861,19 +862,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (agdebug)					\
-    agsymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (agdebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       agsymprint (stderr, 					\
-                  Token, Value);	\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -885,12 +880,12 @@ do {								\
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-ag_stack_print (short *bottom, short *top)
+ag_stack_print (short int *bottom, short int *top)
 #else
 static void
 ag_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -940,8 +935,7 @@ do {					\
 int agdebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -959,10 +953,6 @@ int agdebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -1044,15 +1034,15 @@ agsymprint (agoutput, agtype, agvaluep)
   (void) agvaluep;
 
   if (agtype < YYNTOKENS)
-    {
-      YYFPRINTF (agoutput, "token %s (", agtname[agtype]);
-# ifdef YYPRINT
-      YYPRINT (agoutput, agtoknum[agtype], *agvaluep);
-# endif
-    }
+    YYFPRINTF (agoutput, "token %s (", agtname[agtype]);
   else
     YYFPRINTF (agoutput, "nterm %s (", agtname[agtype]);
 
+
+# ifdef YYPRINT
+  if (agtype < YYNTOKENS)
+    YYPRINT (agoutput, agtoknum[agtype], *agvaluep);
+# endif
   switch (agtype)
     {
       default:
@@ -1068,10 +1058,11 @@ agsymprint (agoutput, agtype, agvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-agdestruct (int agtype, YYSTYPE *agvaluep)
+agdestruct (const char *agmsg, int agtype, YYSTYPE *agvaluep)
 #else
 static void
-agdestruct (agtype, agvaluep)
+agdestruct (agmsg, agtype, agvaluep)
+    const char *agmsg;
     int agtype;
     YYSTYPE *agvaluep;
 #endif
@@ -1079,6 +1070,10 @@ agdestruct (agtype, agvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) agvaluep;
 
+  if (!agmsg)
+    agmsg = "Deleting";
+  YY_SYMBOL_PRINT (agmsg, agtype, agvaluep, aglocationp);
+
   switch (agtype)
     {
 
@@ -1106,10 +1101,10 @@ int agparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int agchar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE aglval;
 
 /* Number of syntax errors so far.  */
@@ -1145,7 +1140,7 @@ agparse ()
   int agresult;
   /* Number of tokens to shift before error messages enabled.  */
   int agerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int agtoken = 0;
 
   /* Three stacks and their tools:
@@ -1157,9 +1152,9 @@ agparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	agssa[YYINITDEPTH];
-  short *agss = agssa;
-  register short *agssp;
+  short int agssa[YYINITDEPTH];
+  short int *agss = agssa;
+  register short int *agssp;
 
   /* The semantic value stack.  */
   YYSTYPE agvsa[YYINITDEPTH];
@@ -1196,6 +1191,9 @@ agparse ()
   agssp = agss;
   agvsp = agvs;
 
+
+  agvsp[0] = aglval;
+
   goto agsetstate;
 
 /*------------------------------------------------------------.
@@ -1221,7 +1219,7 @@ agparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *agvs1 = agvs;
-	short *agss1 = agss;
+	short int *agss1 = agss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -1249,7 +1247,7 @@ agparse ()
 	agstacksize = YYMAXDEPTH;
 
       {
-	short *agss1 = agss;
+	short int *agss1 = agss;
 	union agalloc *agptr =
 	  (union agalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (agstacksize));
 	if (! agptr)
@@ -1285,18 +1283,18 @@ agparse ()
 agbackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* agresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   agn = agpact[agstate];
   if (agn == YYPACT_NINF)
     goto agdefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (agchar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1311,7 +1309,7 @@ agbackup:
   else
     {
       agtoken = YYTRANSLATE (agchar);
-      YYDSYMPRINTF ("Next token is", agtoken, &aglval, &aglloc);
+      YY_SYMBOL_PRINT ("Next token is", agtoken, &aglval, &aglloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1331,8 +1329,8 @@ agbackup:
   if (agn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", agtname[agtoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", agtoken, &aglval, &aglloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (agchar != YYEOF)
@@ -1382,17 +1380,17 @@ agreduce:
   switch (agn)
     {
         case 2:
-#line 342 "../graph/parser.y"
-    {begin_graph(agvsp[0].str); agstrfree(agvsp[0].str);}
+#line 314 "../graph/parser.y"
+    {begin_graph((agvsp[0].str)); agstrfree((agvsp[0].str));}
     break;
 
   case 3:
-#line 344 "../graph/parser.y"
+#line 316 "../graph/parser.y"
     {AG.accepting_state = TRUE; end_graph();}
     break;
 
   case 4:
-#line 346 "../graph/parser.y"
+#line 318 "../graph/parser.y"
     {
 					if (AG.parsed_g)
 						agclose(AG.parsed_g);
@@ -1402,244 +1400,239 @@ agreduce:
     break;
 
   case 5:
-#line 352 "../graph/parser.y"
+#line 324 "../graph/parser.y"
     {AG.parsed_g = NULL;}
     break;
 
   case 6:
-#line 355 "../graph/parser.y"
-    {agval.str=agvsp[0].str;}
+#line 327 "../graph/parser.y"
+    {(agval.str)=(agvsp[0].str);}
     break;
 
   case 7:
-#line 355 "../graph/parser.y"
-    {agval.str=0;}
+#line 327 "../graph/parser.y"
+    {(agval.str)=0;}
     break;
 
   case 8:
-#line 359 "../graph/parser.y"
+#line 331 "../graph/parser.y"
     {Agraph_type = AGRAPH; AG.edge_op = "--";}
     break;
 
   case 9:
-#line 361 "../graph/parser.y"
+#line 333 "../graph/parser.y"
     {Agraph_type = AGRAPHSTRICT; AG.edge_op = "--";}
     break;
 
   case 10:
-#line 363 "../graph/parser.y"
+#line 335 "../graph/parser.y"
     {Agraph_type = AGDIGRAPH; AG.edge_op = "->";}
     break;
 
   case 11:
-#line 365 "../graph/parser.y"
+#line 337 "../graph/parser.y"
     {Agraph_type = AGDIGRAPHSTRICT; AG.edge_op = "->";}
     break;
 
   case 12:
-#line 369 "../graph/parser.y"
+#line 341 "../graph/parser.y"
     {Current_class = TAG_GRAPH;}
     break;
 
   case 13:
-#line 371 "../graph/parser.y"
+#line 343 "../graph/parser.y"
     {Current_class = TAG_NODE; N = G->proto->n;}
     break;
 
   case 14:
-#line 373 "../graph/parser.y"
+#line 345 "../graph/parser.y"
     {Current_class = TAG_EDGE; E = G->proto->e;}
     break;
 
   case 23:
-#line 395 "../graph/parser.y"
-    {attr_set(agvsp[-2].str,agvsp[0].str); agstrfree(agvsp[-2].str); agstrfree(agvsp[0].str);}
+#line 367 "../graph/parser.y"
+    {attr_set((agvsp[-2].str),(agvsp[0].str)); agstrfree((agvsp[-2].str)); agstrfree((agvsp[0].str));}
     break;
 
   case 25:
-#line 400 "../graph/parser.y"
-    {attr_set(agvsp[0].str,"true"); agstrfree(agvsp[0].str); }
+#line 372 "../graph/parser.y"
+    {attr_set((agvsp[0].str),"true"); agstrfree((agvsp[0].str)); }
     break;
 
   case 32:
-#line 413 "../graph/parser.y"
+#line 385 "../graph/parser.y"
     {agerror("syntax error, statement skipped");}
     break;
 
   case 36:
-#line 419 "../graph/parser.y"
+#line 391 "../graph/parser.y"
     {}
     break;
 
   case 37:
-#line 423 "../graph/parser.y"
+#line 395 "../graph/parser.y"
     {Current_class = TAG_GRAPH; /* reset */}
     break;
 
   case 38:
-#line 425 "../graph/parser.y"
+#line 397 "../graph/parser.y"
     {Current_class = TAG_GRAPH;}
     break;
 
   case 39:
-#line 429 "../graph/parser.y"
+#line 401 "../graph/parser.y"
     {
 					objport_t		rv;
-					rv.obj = agvsp[-1].n;
+					rv.obj = (agvsp[-1].n);
 					rv.port = Port;
 					Port = NULL;
-					if (Subport) {
-						rv.subport = Subport;
-						Subport = NULL;
-					}
-					else rv.subport = NULL;
-					agval.obj = rv;
+					(agval.obj) = rv;
 				}
     break;
 
   case 40:
-#line 443 "../graph/parser.y"
-    {agval.n = bind_node(agvsp[0].str); agstrfree(agvsp[0].str);}
+#line 410 "../graph/parser.y"
+    {(agval.n) = bind_node((agvsp[0].str)); agstrfree((agvsp[0].str));}
     break;
 
   case 42:
-#line 447 "../graph/parser.y"
-    {Port=agvsp[0].str;}
+#line 414 "../graph/parser.y"
+    { Port=(agvsp[0].str);}
     break;
 
   case 43:
-#line 448 "../graph/parser.y"
-    {Port=agvsp[-2].str;Subport=agvsp[0].str;}
+#line 415 "../graph/parser.y"
+    {Port=concat3((agvsp[-2].str),":",(agvsp[0].str));agstrfree((agvsp[-2].str)); agstrfree((agvsp[0].str));}
     break;
 
   case 44:
-#line 452 "../graph/parser.y"
-    {Current_class = TAG_NODE; N = (Agnode_t*)(agvsp[0].obj.obj);}
+#line 419 "../graph/parser.y"
+    {Current_class = TAG_NODE; N = (Agnode_t*)((agvsp[0].obj).obj);}
     break;
 
   case 45:
-#line 454 "../graph/parser.y"
-    {free(agvsp[-2].obj.port);Current_class = TAG_GRAPH; /* reset */}
+#line 421 "../graph/parser.y"
+    {free((agvsp[-2].obj).port);Current_class = TAG_GRAPH; /* reset */}
     break;
 
   case 46:
-#line 458 "../graph/parser.y"
-    {begin_edgestmt(agvsp[0].obj);}
+#line 425 "../graph/parser.y"
+    {begin_edgestmt((agvsp[0].obj));}
     break;
 
   case 47:
-#line 460 "../graph/parser.y"
+#line 427 "../graph/parser.y"
     { E = SP->subg->proto->e;
 				  Current_class = TAG_EDGE; }
     break;
 
   case 48:
-#line 463 "../graph/parser.y"
+#line 430 "../graph/parser.y"
     {end_edgestmt();}
     break;
 
   case 49:
-#line 465 "../graph/parser.y"
-    {begin_edgestmt(agvsp[0].obj);}
+#line 432 "../graph/parser.y"
+    {begin_edgestmt((agvsp[0].obj));}
     break;
 
   case 50:
-#line 467 "../graph/parser.y"
+#line 434 "../graph/parser.y"
     { E = SP->subg->proto->e;
 				  Current_class = TAG_EDGE; }
     break;
 
   case 51:
-#line 470 "../graph/parser.y"
+#line 437 "../graph/parser.y"
     {end_edgestmt();}
     break;
 
   case 52:
-#line 473 "../graph/parser.y"
-    {mid_edgestmt(agvsp[0].obj);}
+#line 440 "../graph/parser.y"
+    {mid_edgestmt((agvsp[0].obj));}
     break;
 
   case 53:
-#line 475 "../graph/parser.y"
-    {mid_edgestmt(agvsp[0].obj);}
+#line 442 "../graph/parser.y"
+    {mid_edgestmt((agvsp[0].obj));}
     break;
 
   case 55:
-#line 478 "../graph/parser.y"
-    {mid_edgestmt(agvsp[0].obj);}
+#line 445 "../graph/parser.y"
+    {mid_edgestmt((agvsp[0].obj));}
     break;
 
   case 56:
-#line 480 "../graph/parser.y"
-    {mid_edgestmt(agvsp[0].obj);}
+#line 447 "../graph/parser.y"
+    {mid_edgestmt((agvsp[0].obj));}
     break;
 
   case 58:
-#line 485 "../graph/parser.y"
-    {agval.obj = pop_gobj();}
+#line 452 "../graph/parser.y"
+    {(agval.obj) = pop_gobj();}
     break;
 
   case 59:
-#line 486 "../graph/parser.y"
+#line 453 "../graph/parser.y"
     { anonsubg(); }
     break;
 
   case 60:
-#line 486 "../graph/parser.y"
-    {agval.obj = pop_gobj();}
+#line 453 "../graph/parser.y"
+    {(agval.obj) = pop_gobj();}
     break;
 
   case 61:
-#line 487 "../graph/parser.y"
+#line 454 "../graph/parser.y"
     { anonsubg(); }
     break;
 
   case 62:
-#line 487 "../graph/parser.y"
-    {agval.obj = pop_gobj();}
+#line 454 "../graph/parser.y"
+    {(agval.obj) = pop_gobj();}
     break;
 
   case 63:
-#line 488 "../graph/parser.y"
-    {agval.obj = pop_gobj();}
+#line 455 "../graph/parser.y"
+    {(agval.obj) = pop_gobj();}
     break;
 
   case 64:
-#line 492 "../graph/parser.y"
+#line 459 "../graph/parser.y"
     { Agraph_t	 *subg;
-				if ((subg = agfindsubg(AG.parsed_g,agvsp[0].str))) aginsert(G,subg);
-				else subg = agsubg(G,agvsp[0].str); 
+				if ((subg = agfindsubg(AG.parsed_g,(agvsp[0].str)))) aginsert(G,subg);
+				else subg = agsubg(G,(agvsp[0].str)); 
 				push_subg(subg);
 				In_decl = FALSE;
-				agstrfree(agvsp[0].str);
+				agstrfree((agvsp[0].str));
 				}
     break;
 
   case 65:
-#line 501 "../graph/parser.y"
-    {agval.str = agvsp[0].str; }
+#line 468 "../graph/parser.y"
+    {(agval.str) = (agvsp[0].str); }
     break;
 
   case 66:
-#line 502 "../graph/parser.y"
-    {agval.str = agvsp[0].str; }
+#line 469 "../graph/parser.y"
+    {(agval.str) = (agvsp[0].str); }
     break;
 
   case 67:
-#line 505 "../graph/parser.y"
-    {agval.str = agvsp[0].str; }
+#line 472 "../graph/parser.y"
+    {(agval.str) = (agvsp[0].str); }
     break;
 
   case 68:
-#line 506 "../graph/parser.y"
-    {agval.str = concat(agvsp[-2].str,agvsp[0].str); agstrfree(agvsp[-2].str); agstrfree(agvsp[0].str);}
+#line 473 "../graph/parser.y"
+    {(agval.str) = concat((agvsp[-2].str),(agvsp[0].str)); agstrfree((agvsp[-2].str)); agstrfree((agvsp[0].str));}
     break;
 
 
     }
 
-/* Line 1000 of yacc.c.  */
-#line 1643 "y.tab.c"
+/* Line 1037 of yacc.c.  */
+#line 1636 "y.tab.c"
 
   agvsp -= aglen;
   agssp -= aglen;
@@ -1739,7 +1732,7 @@ agerrlab:
 
   if (agerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (agchar <= YYEOF)
@@ -1749,23 +1742,22 @@ agerrlab:
 	  if (agchar == YYEOF)
 	     for (;;)
 	       {
+
 		 YYPOPSTACK;
 		 if (agssp == agss)
 		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", agstos[*agssp], agvsp, aglsp);
-		 agdestruct (agstos[*agssp], agvsp);
+		 agdestruct ("Error: popping",
+                             agstos[*agssp], agvsp);
 	       }
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", agtoken, &aglval, &aglloc);
-	  agdestruct (agtoken, &aglval);
+	  agdestruct ("Error: discarding", agtoken, &aglval);
 	  agchar = YYEMPTY;
-
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto agerrlab1;
 
@@ -1782,7 +1774,7 @@ agerrorlab:
      goto agerrorlab;
 #endif
 
-  agvsp -= aglen;
+agvsp -= aglen;
   agssp -= aglen;
   agstate = *agssp;
   goto agerrlab1;
@@ -1812,8 +1804,8 @@ agerrlab1:
       if (agssp == agss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", agstos[*agssp], agvsp, aglsp);
-      agdestruct (agstos[agstate], agvsp);
+
+      agdestruct ("Error: popping", agstos[agstate], agvsp);
       YYPOPSTACK;
       agstate = *agssp;
       YY_STACK_PRINT (agss, agssp);
@@ -1822,11 +1814,12 @@ agerrlab1:
   if (agn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++agvsp = aglval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", agstos[agn], agvsp, aglsp);
+
   agstate = agn;
   goto agnewstate;
 
@@ -1842,6 +1835,9 @@ agacceptlab:
 | agabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 agabortlab:
+  agdestruct ("Error: discarding lookahead",
+              agtoken, &aglval);
+  agchar = YYEMPTY;
   agresult = 1;
   goto agreturn;
 
@@ -1864,7 +1860,7 @@ agreturn:
 }
 
 
-#line 508 "../graph/parser.y"
+#line 475 "../graph/parser.y"
 
 #ifdef UNUSED
 /* grammar allowing port variants */
