@@ -1178,7 +1178,12 @@ quartz_polyline(point* A,int n)
 static  void
 quartz_user_shape(char *name, point *A, int n, int filled)
 {
-	CFTypeRef image = fetch_image (agget(current_node,"shapefile"));
+	CFTypeRef image;
+
+	if (streq(name,"custom"))
+		image = fetch_image (agget(current_node,"shapefile"));
+	else
+		image = fetch_image (name);
 	if (image) {
 		pointf	min, max;		/* upper left, lower right */
 		int i;
@@ -1223,7 +1228,7 @@ gd_textsize(char* str, char* fontname, double fontsz, pointf* textsize)
     return NULL;
 }
 
-point quartz_user_shape_size(node_t *n, char *shapeimagefile)
+point quartz_image_size(graph_t *g, char *shapeimagefile)
 {
 	point	rv = {-1, -1};
 	
@@ -1244,6 +1249,11 @@ point quartz_user_shape_size(node_t *n, char *shapeimagefile)
 	return rv;
 }
 
+point quartz_user_shape_size(node_t *n, char *shapeimagefile)
+{
+	return (quartz_image_size (n->graph, shapeimagefile));
+}
+
 codegen_t QPDF_CodeGen = {
     quartz_reset,
     quartz_begin_job_for_pdf,
