@@ -1,4 +1,4 @@
-/* $Id: tcldot.c,v 1.75 2004/12/11 19:26:11 ellson Exp $ $Revision: 1.75 $ */
+/* $Id: tcldot.c,v 1.76 2005/04/05 18:46:51 ellson Exp $ $Revision: 1.76 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -66,7 +66,7 @@ extern int Output_lang;
 #endif
 #endif
 extern void *GDHandleTable;
-extern int Gdtclft_Init();
+extern int Gdtclft_Init(Tcl_Interp *);
 
 static void *graphTblPtr, *nodeTblPtr, *edgeTblPtr;
 static tkgendata_t tkgendata;
