@@ -1,4 +1,4 @@
-/* $Id: find_ints.c,v 1.5 2004/12/11 19:26:11 ellson Exp $ $Revision: 1.5 $ */
+/* $Id: find_ints.c,v 1.6 2005/04/05 18:44:57 ellson Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -20,6 +20,7 @@
 
 void find_intersection(struct vertex *l, struct vertex *m,
 		       struct intersection ilist[], struct data *input);
+static int gt(struct vertex **i, struct vertex **j);
 
 void find_ints(vertex_list, polygon_list, input, ilist)
 struct vertex vertex_list[];
@@ -27,7 +28,7 @@ struct polygon polygon_list[];
 struct data *input;
 struct intersection ilist[];
 {
-    int i, j, k, gt();
+    int i, j, k;
     struct active_edge_list all;
     struct active_edge *new, *tempa;
     struct vertex *pt1, *pt2, *templ, **pvertex;
@@ -44,7 +45,8 @@ struct intersection ilist[];
 	pvertex[i] = vertex_list + i;
 
 /* sort vertices by x coordinate	*/
-    qsort(pvertex, input->nvertices, sizeof(struct vertex *), gt);
+    qsort(pvertex, input->nvertices, sizeof(struct vertex *),
+    	  (int (*)(const void *, const void *))gt);
 
 /* walk through the vertices in order of increasing x coordinate	*/
     for (i = 0; i < input->nvertices; i++) {
@@ -111,8 +113,7 @@ struct intersection ilist[];
     }				/* end i for loop       */
 }
 
-int gt(i, j)
-struct vertex **i, **j;
+static int gt(struct vertex **i, struct vertex **j)
 {				/* i > j if i.x > j.x or i.x = j.x and i.y > j.y  */
     double t;
     if ((t = (*i)->pos.x - (*j)->pos.x) != 0.)
