@@ -1,4 +1,4 @@
-/* $Id: exgram.h,v 1.21 2004/12/11 19:26:11 ellson Exp $ $Revision: 1.21 $ */
+/* $Id: exgram.h,v 1.22 2004/12/14 22:54:19 erg Exp $ $Revision: 1.22 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -594,6 +594,8 @@ extern "C" {
 		    exerror("%s: trailing %% in format", f);
 		if (*s != '%')
 		    break;
+		if (args)
+		    sfputc(expr.program->tmp, '%');
 	    }
 	}
 	x = 0;
