@@ -1,3 +1,19 @@
+/* $Id: sfhdr.h,v 1.5 2004/12/11 19:26:11 ellson Exp $ $Revision: 1.5 $ */
+/* vim:set shiftwidth=4 ts=8: */
+
+/**********************************************************
+*      This software is part of the graphviz package      *
+*                http://www.graphviz.org/                 *
+*                                                         *
+*            Copyright (c) 1994-2004 AT&T Corp.           *
+*                and is licensed under the                *
+*            Common Public License, Version 1.0           *
+*                      by AT&T Corp.                      *
+*                                                         *
+*        Information and Software Systems Research        *
+*              AT&T Research, Florham Park NJ             *
+**********************************************************/
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -34,7 +50,7 @@ extern "C" {
 #define _lib_locale	1
 #endif
 
-#else /*!_PACKAGE_ast*/
+#else				/*!_PACKAGE_ast */
 
 #if __mips == 2 && !defined(_NO_LARGEFILE64_SOURCE)
 #define _NO_LARGEFILE64_SOURCE  1
@@ -67,6 +83,7 @@ extern "C" {
 #undef  _hdr_floatingpoint
 #undef  _hdr_float
 #undef  _hdr_values
+#undef  _hdr_limits
 #undef  _hdr_math
 #undef  _sys_mman
 #undef  _hdr_mman
@@ -115,7 +132,7 @@ extern "C" {
 #endif /*_sys_filio*/
 #endif /*_hdr_filio*/
 #endif /*_FIOCLEX*/
-#endif /*F_SETFD*/
+#endif				/*F_SETFD */
 
 #if _hdr_unistd
 #include	<unistd.h>
@@ -143,9 +160,9 @@ extern "C" {
 #define POOLMTXSTART(p)		{ POOLMTXLOCK(p); }
 #define POOLMTXRETURN(p,v)	{ POOLMTXUNLOCK(p); return(v); }
 
-#else /*!vt_threaded*/
+#else				/*!vt_threaded */
 
-#undef SF_MTSAFE /* no need to worry about thread-safety */
+#undef SF_MTSAFE		/* no need to worry about thread-safety */
 #define SF_MTSAFE		0
 
 #define SFONCE()		(void)(0)
@@ -160,7 +177,7 @@ extern "C" {
 #define POOLMTXSTART(p)
 #define POOLMTXRETURN(p,v)	{ return(v); }
 
-#endif /*vt_threaded*/
+#endif				/*vt_threaded */
 
 
 /* functions for polling readiness of streams */
@@ -220,8 +237,8 @@ extern "C" {
 #endif
 #endif
 
-#ifdef MAXFLOAT	/* on some platforms, these are defined in both values.h and math.h */
-#undef MAXFLOAT	/* we don't need them so we zap them here to avoid compiler warnings */
+#ifdef MAXFLOAT			/* on some platforms, these are defined in both values.h and math.h */
+#undef MAXFLOAT			/* we don't need them so we zap them here to avoid compiler warnings */
 #endif
 #ifdef MAXSHORT
 #undef MAXSHORT
@@ -233,6 +250,9 @@ extern "C" {
 #undef MAXLONG
 #endif
 
+#if _hdr_limits
+#include	<limits.h>
+#else
 #if _hdr_values
 #include	<values.h>
 #if !defined(SF_MAXDOUBLE) && defined(MAXDOUBLE)
@@ -242,6 +262,7 @@ extern "C" {
 #define SF_MAXDOUBLE	DBL_MAX
 #endif
 #endif
+#endif
 
 #if !defined(SF_MAXDOUBLE) && _hdr_floatingpoint
 #include	<floatingpoint.h>
@@ -282,13 +303,13 @@ extern "C" {
 /* 64-bit vs 32-bit file stuff */
 #if _sys_stat
 #ifdef _LARGEFILE64_SOURCE
-typedef struct stat64	Stat_t;
+    typedef struct stat64 Stat_t;
 #define	lseek		lseek64
 #define stat		stat64
 #define fstat		fstat64
 #define off_t		off64_t
 #else
-typedef struct stat	Stat_t;
+    typedef struct stat Stat_t;
 #endif
 #endif
 
@@ -300,21 +321,21 @@ typedef struct stat	Stat_t;
 #endif
 
 /* Private flags in the "bits" field */
-#define SF_MMAP		00000001	/* in memory mapping mode		*/
-#define SF_BOTH		00000002	/* both read/write			*/
-#define SF_HOLE		00000004	/* a hole of zero's was created		*/
-#define SF_NULL		00000010	/* stream is /dev/null			*/
-#define SF_SEQUENTIAL	00000020	/* sequential access			*/
-#define SF_JUSTSEEK	00000040	/* just did a sfseek			*/
+#define SF_MMAP		00000001	/* in memory mapping mode               */
+#define SF_BOTH		00000002	/* both read/write                      */
+#define SF_HOLE		00000004	/* a hole of zero's was created         */
+#define SF_NULL		00000010	/* stream is /dev/null                  */
+#define SF_SEQUENTIAL	00000020	/* sequential access                    */
+#define SF_JUSTSEEK	00000040	/* just did a sfseek                    */
 
 /* this bit signals sfmutex() not to create a mutex for a private stream */
-#define SF_PRIVATE	00000200	/* private stream to Sfio		*/
+#define SF_PRIVATE	00000200	/* private stream to Sfio               */
 
 /* on closing, don't be a hero about reread/rewrite on interrupts */
 #define SF_ENDING	00000400
 
 /* private flags that must be cleared in sfclrlock */
-#define SF_DCDOWN	00001000	/* recurse down the discipline stack	*/
+#define SF_DCDOWN	00001000	/* recurse down the discipline stack    */
 #define SF_MVSIZE	00002000
 #define SFMVSET(f)	(((f)->size *= SF_NMAP), ((f)->bits |= SF_MVSIZE) )
 #define SFMVUNSET(f)	(!((f)->bits&SF_MVSIZE) ? 0 : \
@@ -322,18 +343,18 @@ typedef struct stat	Stat_t;
 #define SFCLRBITS(f)	(SFMVUNSET(f), ((f)->bits &= ~(SF_DCDOWN|SF_MVSIZE)) )
 
 /* bits for the mode field, SF_INIT defined in sfio_t.h */
-#define SF_RC		00000010	/* peeking for a record			*/
-#define SF_RV		00000020	/* reserve without read	or most write	*/
-#define SF_LOCK		00000040	/* stream is locked for io op		*/
-#define SF_PUSH		00000100	/* stream has been pushed		*/
-#define SF_POOL		00000200	/* stream is in a pool but not current	*/
-#define SF_PEEK		00000400	/* there is a pending peek		*/
-#define SF_PKRD		00001000	/* did a peek read			*/
-#define SF_GETR		00002000	/* did a getr on this stream		*/
-#define SF_SYNCED	00004000	/* stream was synced			*/
-#define SF_STDIO	00010000	/* given up the buffer to stdio		*/
-#define SF_AVAIL	00020000	/* was closed, available for reuse	*/
-#define SF_LOCAL	00100000	/* sentinel for a local call		*/
+#define SF_RC		00000010	/* peeking for a record                 */
+#define SF_RV		00000020	/* reserve without read or most write   */
+#define SF_LOCK		00000040	/* stream is locked for io op           */
+#define SF_PUSH		00000100	/* stream has been pushed               */
+#define SF_POOL		00000200	/* stream is in a pool but not current  */
+#define SF_PEEK		00000400	/* there is a pending peek              */
+#define SF_PKRD		00001000	/* did a peek read                      */
+#define SF_GETR		00002000	/* did a getr on this stream            */
+#define SF_SYNCED	00004000	/* stream was synced                    */
+#define SF_STDIO	00010000	/* given up the buffer to stdio         */
+#define SF_AVAIL	00020000	/* was closed, available for reuse      */
+#define SF_LOCAL	00100000	/* sentinel for a local call            */
 
 #ifdef DEBUG
 #define ASSERT(p)	((p) ? 0 : (abort(),0) )
@@ -404,7 +425,7 @@ typedef struct stat	Stat_t;
 #ifdef F_SETFD
 #	ifndef FD_CLOEXEC
 #		define FD_CLOEXEC	1
-#	endif /*FD_CLOEXEC*/
+#	endif			/*FD_CLOEXEC */
 #	define SETCLOEXEC(fd)		((void)fcntl((fd),F_SETFD,FD_CLOEXEC))
 #else
 #	ifdef FIOCLEX
@@ -412,8 +433,7 @@ typedef struct stat	Stat_t;
 #	else
 #		define SETCLOEXEC(fd)
 #	endif /*FIOCLEX*/
-#endif /*F_SETFD*/
-
+#endif				/*F_SETFD */
 /* a couple of error number that we use, default values are like Linux */
 #ifndef EINTR
 #define EINTR	4
@@ -433,7 +453,6 @@ typedef struct stat	Stat_t;
 #ifndef ESPIPE
 #define ESPIPE	29
 #endif
-
 /* see if we can use memory mapping for io */
 #if !_PACKAGE_ast && _mmap_worthy
 #	ifdef _LARGEFILE64_SOURCE
@@ -452,10 +471,9 @@ typedef struct stat	Stat_t;
 #		define mmap		mmap64
 #	endif
 #endif
-
 /* function to get the decimal point for local environment */
 #if _lib_locale
-#ifdef MAXFLOAT	/* we don't need these, so we zap them to avoid compiler warnings */
+#ifdef MAXFLOAT			/* we don't need these, so we zap them to avoid compiler warnings */
 #undef MAXFLOAT
 #endif
 #ifdef MAXSHORT
@@ -467,7 +485,6 @@ typedef struct stat	Stat_t;
 #ifdef MAXLONG
 #undef MAXLONG
 #endif
-
 #include	<locale.h>
 #define SFSETLOCALE(decimal,thousand) \
 	{ struct lconv*	lv; \
@@ -484,37 +501,36 @@ typedef struct stat	Stat_t;
 #else
 #define SFSETLOCALE(decimal,thousand)
 #endif
-
 /* stream pool structure. */
-typedef struct _sfpool_s	Sfpool_t;
-struct _sfpool_s
-{	Sfpool_t*	next;
-	int		mode;		/* type of pool			*/
-	int		s_sf;		/* size of pool array		*/
-	int		n_sf;		/* number currently in pool	*/
-	Sfio_t**	sf;		/* array of streams		*/
-	Sfio_t*		array[3];	/* start with 3			*/
-	Vtmutex_t	mutex;		/* mutex lock object		*/
-};
+    typedef struct _sfpool_s Sfpool_t;
+    struct _sfpool_s {
+	Sfpool_t *next;
+	int mode;		/* type of pool                 */
+	int s_sf;		/* size of pool array           */
+	int n_sf;		/* number currently in pool     */
+	Sfio_t **sf;		/* array of streams             */
+	Sfio_t *array[3];	/* start with 3                 */
+	Vtmutex_t mutex;	/* mutex lock object            */
+    };
 
 /* reserve buffer structure */
-typedef struct _sfrsrv_s	Sfrsrv_t;
-struct _sfrsrv_s
-{	ssize_t		slen;		/* last string length		*/
-	ssize_t		size;		/* buffer size			*/
-	uchar		data[1];	/* data buffer			*/
-};
+    typedef struct _sfrsrv_s Sfrsrv_t;
+    struct _sfrsrv_s {
+	ssize_t slen;		/* last string length           */
+	ssize_t size;		/* buffer size                  */
+	uchar data[1];		/* data buffer                  */
+    };
 
 /* co-process structure */
-typedef struct _sfproc_s	Sfproc_t;
-struct _sfproc_s
-{	int		pid;	/* process id			*/
-	uchar*		rdata;	/* read data being cached	*/
-	int		ndata;	/* size of cached data		*/
-	int		size;	/* buffer size			*/
-	int		file;	/* saved file descriptor	*/
-	int		sigp;	/* sigpipe protection needed	*/
-};
+    typedef struct _sfproc_s Sfproc_t;
+    struct _sfproc_s {
+	int pid;		/* process id                   */
+	uchar *rdata;		/* read data being cached       */
+	int ndata;		/* size of cached data          */
+	int size;		/* buffer size                  */
+	int file;		/* saved file descriptor        */
+	int sigp;		/* sigpipe protection needed    */
+    };
 
 /* extensions to sfvprintf/sfvscanf */
 #define FP_SET(fp,fn)	(fp < 0 ? (fn += 1) : (fn = fp) )
@@ -523,47 +539,47 @@ struct _sfproc_s
 #define FP_BASE		2
 #define FP_STR		3
 #define FP_SIZE		4
-#define FP_INDEX	5	/* index size	*/
+#define FP_INDEX	5	/* index size   */
 
-typedef struct _fmt_s		Fmt_t;
-typedef struct _fmtpos_s	Fmtpos_t;
-typedef union
-{	int		i, *ip;
-	long		l, *lp;
-	short		h, *hp;
-	uint		ui;
-	ulong		ul;
-	ushort		uh;
-	Sflong_t	ll, *llp;
-	Sfulong_t	lu;
-	Sfdouble_t	ld;
-	double		d;
-	float		f;
-	char		c, *s, **sp;
-	Void_t		*vp;
-	Sffmt_t		*ft;
-} Argv_t;
+    typedef struct _fmt_s Fmt_t;
+    typedef struct _fmtpos_s Fmtpos_t;
+    typedef union {
+	int i, *ip;
+	long l, *lp;
+	short h, *hp;
+	uint ui;
+	ulong ul;
+	ushort uh;
+	Sflong_t ll, *llp;
+	Sfulong_t lu;
+	Sfdouble_t ld;
+	double d;
+	float f;
+	char c, *s, **sp;
+	Void_t *vp;
+	Sffmt_t *ft;
+    } Argv_t;
 
-struct _fmt_s
-{	char*		form;		/* format string		*/
-	va_list		args;		/* corresponding arglist	*/
+    struct _fmt_s {
+	char *form;		/* format string                */
+	va_list args;		/* corresponding arglist        */
 
-	char*		oform;		/* original format string	*/
-	va_list		oargs;		/* original arg list		*/
-	int		argn;		/* number of args already used	*/
-	Fmtpos_t*	fp;		/* position list		*/
+	char *oform;		/* original format string       */
+	va_list oargs;		/* original arg list            */
+	int argn;		/* number of args already used  */
+	Fmtpos_t *fp;		/* position list                */
 
-	Sffmt_t*	ft;		/* formatting environment	*/
-	Sffmtevent_f	eventf;		/* event function		*/
-	Fmt_t*		next;		/* stack frame pointer		*/
-};
+	Sffmt_t *ft;		/* formatting environment       */
+	Sffmtevent_f eventf;	/* event function               */
+	Fmt_t *next;		/* stack frame pointer          */
+    };
 
-struct _fmtpos_s
-{	Sffmt_t	ft;			/* environment			*/
-	Argv_t	argv;			/* argument value		*/
-	int	fmt;			/* original format		*/
-	int	need[FP_INDEX];		/* positions depending on	*/
-};
+    struct _fmtpos_s {
+	Sffmt_t ft;		/* environment                  */
+	Argv_t argv;		/* argument value               */
+	int fmt;		/* original format              */
+	int need[FP_INDEX];	/* positions depending on       */
+    };
 
 #define LEFTP		'('
 #define RIGHTP		')'
@@ -588,21 +604,21 @@ struct _fmtpos_s
 	 (sz == 64 && sz == sizeof(type)*CHAR_BIT) )
 
 /* format flags&types, must coexist with those in sfio.h */
-#define SFFMT_FORBIDDEN 00077777777	/* for sfio.h only	*/
-#define SFFMT_EFORMAT	01000000000	/* sfcvt converting %e	*/
-#define SFFMT_MINUS	02000000000	/* minus sign		*/
+#define SFFMT_FORBIDDEN 00077777777	/* for sfio.h only      */
+#define SFFMT_EFORMAT	01000000000	/* sfcvt converting %e  */
+#define SFFMT_MINUS	02000000000	/* minus sign           */
 
 #define SFFMT_TYPES	(SFFMT_SHORT|SFFMT_SSHORT | SFFMT_LONG|SFFMT_LLONG|\
 			 SFFMT_LDOUBLE | SFFMT_IFLAG|SFFMT_JFLAG| \
 			 SFFMT_TFLAG | SFFMT_ZFLAG )
 
 /* type of elements to be converted */
-#define SFFMT_INT	001		/* %d,%i 		*/
-#define SFFMT_UINT	002		/* %u,o,x etc.		*/
-#define SFFMT_FLOAT	004		/* %f,e,g etc.		*/
-#define SFFMT_BYTE	010		/* %c			*/
-#define SFFMT_POINTER	020		/* %p, %n		*/
-#define SFFMT_CLASS	040		/* %[			*/
+#define SFFMT_INT	001	/* %d,%i                */
+#define SFFMT_UINT	002	/* %u,o,x etc.          */
+#define SFFMT_FLOAT	004	/* %f,e,g etc.          */
+#define SFFMT_BYTE	010	/* %c                   */
+#define SFFMT_POINTER	020	/* %p, %n               */
+#define SFFMT_CLASS	040	/* %[                   */
 
 /* local variables used across sf-functions */
 #define _Sfpage		(_Sfextern.sf_page)
@@ -618,21 +634,21 @@ struct _fmtpos_s
 #define _Sfonce		(_Sfextern.sf_once)
 #define _Sfoncef	(_Sfextern.sf_oncef)
 #define _Sfmutex	(_Sfextern.sf_mutex)
-typedef struct _sfextern_s
-{	ssize_t			sf_page;
-	struct _sfpool_s	sf_pool;
-	int			(*sf_pmove)_ARG_((Sfio_t*, int));
-	Sfio_t*			(*sf_stack)_ARG_((Sfio_t*, Sfio_t*));
-	void			(*sf_notify)_ARG_((Sfio_t*, int, int));
-	int			(*sf_stdsync)_ARG_((Sfio_t*));
-	struct _sfdisc_s	sf_udisc;
-	void			(*sf_cleanup)_ARG_((void));
-	int			sf_exiting;
-	int			sf_done;
-	Vtonce_t*		sf_once;
-	void			(*sf_oncef)_ARG_((void));
-	Vtmutex_t*		sf_mutex;
-} Sfextern_t;
+    typedef struct _sfextern_s {
+	ssize_t sf_page;
+	struct _sfpool_s sf_pool;
+	int (*sf_pmove) _ARG_((Sfio_t *, int));
+	Sfio_t *(*sf_stack) _ARG_((Sfio_t *, Sfio_t *));
+	void (*sf_notify) _ARG_((Sfio_t *, int, int));
+	int (*sf_stdsync) _ARG_((Sfio_t *));
+	struct _sfdisc_s sf_udisc;
+	void (*sf_cleanup) _ARG_((void));
+	int sf_exiting;
+	int sf_done;
+	Vtonce_t *sf_once;
+	void (*sf_oncef) _ARG_((void));
+	Vtmutex_t *sf_mutex;
+    } Sfextern_t;
 
 /* get the real value of a byte in a coded long or ulong */
 #define SFUVALUE(v)	(((ulong)(v))&(SF_MORE-1))
@@ -684,10 +700,10 @@ typedef struct _sfextern_s
 #define SFKILLED(f)	(((f)->mode&(SF_AVAIL|SF_LOCK)) == (SF_AVAIL|SF_LOCK) )
 
 /* exception types */
-#define SF_EDONE	0	/* stop this operation and return	*/
-#define SF_EDISC	1	/* discipline says it's ok		*/
-#define SF_ESTACK	2	/* stack was popped			*/
-#define SF_ECONT	3	/* can continue normally		*/
+#define SF_EDONE	0	/* stop this operation and return       */
+#define SF_EDISC	1	/* discipline says it's ok              */
+#define SF_ESTACK	2	/* stack was popped                     */
+#define SF_ECONT	3	/* can continue normally                */
 
 #define SETLOCAL(f)	((f)->mode |= SF_LOCAL)
 #define GETLOCAL(f,v)	((v) = ((f)->mode&SF_LOCAL), (f)->mode &= ~SF_LOCAL, (v))
@@ -772,7 +788,7 @@ typedef struct _sfextern_s
 /* control flags for open() */
 #ifdef O_CREAT
 #define _has_oflags	1
-#else	/* for example, research UNIX */
+#else				/* for example, research UNIX */
 #define _has_oflags	0
 #define O_CREAT		004
 #define O_TRUNC		010
@@ -788,7 +804,7 @@ typedef struct _sfextern_s
 #ifndef O_RDWR
 #define O_RDWR		002
 #endif
-#endif /*O_CREAT*/
+#endif				/*O_CREAT */
 
 #ifndef O_BINARY
 #define O_BINARY	000
@@ -816,11 +832,11 @@ typedef struct _sfextern_s
 #define SF_MAXEXP10	6
 #define SF_MAXPOW10	(1 << SF_MAXEXP10)
 #if !_ast_fltmax_double
-#define SF_FDIGITS	1024		/* max allowed fractional digits */
+#define SF_FDIGITS	1024	/* max allowed fractional digits */
 #define SF_IDIGITS	(8*1024)	/* max number of digits in int part */
 #else
-#define SF_FDIGITS	256		/* max allowed fractional digits */
-#define SF_IDIGITS	1024		/* max number of digits in int part */
+#define SF_FDIGITS	256	/* max allowed fractional digits */
+#define SF_IDIGITS	1024	/* max number of digits in int part */
 #endif
 #define SF_MAXDIGITS	(((SF_FDIGITS+SF_IDIGITS)/sizeof(int) + 1)*sizeof(int))
 
@@ -836,19 +852,20 @@ typedef struct _sfextern_s
 #define _Sfcv36		(_Sftable.sf_cv36)
 #define _Sfcv64		(_Sftable.sf_cv64)
 #define _Sftype		(_Sftable.sf_type)
-typedef struct _sftab_
-{	Sfdouble_t	sf_pos10[SF_MAXEXP10];	/* positive powers of 10	*/
-	Sfdouble_t	sf_neg10[SF_MAXEXP10];	/* negative powers of 10	*/
-	uchar		sf_dec[200];		/* ascii reps of values < 100	*/
-	char*		sf_digits;		/* digits for general bases	*/ 
-	int		(*sf_cvinitf)();	/* initialization function	*/
-	int		sf_cvinit;		/* initialization state		*/
-	Fmtpos_t*	(*sf_fmtposf)_ARG_((Sfio_t*,const char*,va_list,int));
-	char*		(*sf_fmtintf)_ARG_((const char*,int*));
-	uchar		sf_cv36[SF_MAXCHAR+1];	/* conversion for base [2-36]	*/
-	uchar		sf_cv64[SF_MAXCHAR+1];	/* conversion for base [37-64]	*/
-	uchar		sf_type[SF_MAXCHAR+1];	/* conversion formats&types	*/
-} Sftab_t;
+    typedef struct _sftab_ {
+	Sfdouble_t sf_pos10[SF_MAXEXP10];	/* positive powers of 10        */
+	Sfdouble_t sf_neg10[SF_MAXEXP10];	/* negative powers of 10        */
+	uchar sf_dec[200];	/* ascii reps of values < 100   */
+	char *sf_digits;	/* digits for general bases     */
+	int (*sf_cvinitf) ();	/* initialization function      */
+	int sf_cvinit;		/* initialization state         */
+	Fmtpos_t *(*sf_fmtposf)
+	    _ARG_((Sfio_t *, const char *, va_list, int));
+	char *(*sf_fmtintf) _ARG_((const char *, int *));
+	uchar sf_cv36[SF_MAXCHAR + 1];	/* conversion for base [2-36]   */
+	uchar sf_cv64[SF_MAXCHAR + 1];	/* conversion for base [37-64]  */
+	uchar sf_type[SF_MAXCHAR + 1];	/* conversion formats&types     */
+    } Sftab_t;
 
 /* thread-safe macro/function to initialize _Sfcv* conversion tables */
 #define SFCVINIT()      (_Sfcvinit ? 1 : (_Sfcvinit = (*_Sfcvinitf)()) )
@@ -943,128 +960,124 @@ typedef struct _sftab_
 	  case  1 : *s++ = c; \
 	}
 
-_BEGIN_EXTERNS_
+     _BEGIN_EXTERNS_ extern Sfextern_t _Sfextern;
+    extern Sftab_t _Sftable;
 
-extern Sfextern_t	_Sfextern;
-extern Sftab_t		_Sftable;
-
-extern int		_sfpopen _ARG_((Sfio_t*, int, int, int));
-extern int		_sfpclose _ARG_((Sfio_t*));
-extern int		_sfmode _ARG_((Sfio_t*, int, int));
-extern int		_sftype _ARG_((const char*, int*, int*));
-extern int		_sfexcept _ARG_((Sfio_t*, int, ssize_t, Sfdisc_t*));
-extern Sfrsrv_t*	_sfrsrv _ARG_((Sfio_t*, ssize_t));
-extern int		_sfsetpool _ARG_((Sfio_t*));
-extern char*		_sfcvt _ARG_((Void_t*, int, int*, int*, int));
-extern char**		_sfgetpath _ARG_((char*));
-extern Sfdouble_t	_sfstrtod _ARG_((const char*, char**));
+    extern int _sfpopen _ARG_((Sfio_t *, int, int, int));
+    extern int _sfpclose _ARG_((Sfio_t *));
+    extern int _sfmode _ARG_((Sfio_t *, int, int));
+    extern int _sftype _ARG_((const char *, int *, int *));
+    extern int _sfexcept _ARG_((Sfio_t *, int, ssize_t, Sfdisc_t *));
+    extern Sfrsrv_t *_sfrsrv _ARG_((Sfio_t *, ssize_t));
+    extern int _sfsetpool _ARG_((Sfio_t *));
+    extern char *_sfcvt _ARG_((Void_t *, int, int *, int *, int));
+    extern char **_sfgetpath _ARG_((char *));
+    extern Sfdouble_t _sfstrtod _ARG_((const char *, char **));
 
 #if !_lib_strtod
 #define strtod		_sfstrtod
 #endif
 
 #ifndef errno
-_astimport int		errno;
+    _astimport int errno;
 #endif
 
 /* for portable encoding of double values */
 #if !__STDC__
-extern double	frexp _ARG_((double, int*));
-extern double	ldexp _ARG_((double,int));
+    extern double frexp _ARG_((double, int *));
+    extern double ldexp _ARG_((double, int));
 #endif
 
 #if !_hdr_mman && !_sys_mman
-extern Void_t*	mmap _ARG_((Void_t*, size_t, int, int, int, off_t));
-extern int	munmap _ARG_((Void_t*, size_t));
+    extern Void_t *mmap _ARG_((Void_t *, size_t, int, int, int, off_t));
+    extern int munmap _ARG_((Void_t *, size_t));
 #endif
 
 #if !_PACKAGE_ast
 
 #if /*!__STDC__ &&*/ !_hdr_stdlib
-extern void	abort _ARG_((void));
-extern int	atexit _ARG_((void(*)(void)));
-extern char*	getenv _ARG_((const char*));
-extern void*	malloc _ARG_((size_t));
-extern void*	realloc _ARG_((void*, size_t));
-extern void	free _ARG_((void*));
-extern size_t	strlen _ARG_((const char*));
-extern char*	strcpy _ARG_((char*, const char*));
+    extern void abort _ARG_((void));
+    extern int atexit _ARG_((void (*)(void)));
+    extern char *getenv _ARG_((const char *));
+    extern void *malloc _ARG_((size_t));
+    extern void *realloc _ARG_((void *, size_t));
+    extern void free _ARG_((void *));
+    extern size_t strlen _ARG_((const char *));
+    extern char *strcpy _ARG_((char *, const char *));
 
-extern Void_t*	memset _ARG_((void*, int, size_t));
-extern Void_t*	memchr _ARG_((const void*, int, size_t));
-extern Void_t*	memccpy _ARG_((void*, const void*, int, size_t));
+    extern Void_t *memset _ARG_((void *, int, size_t));
+    extern Void_t *memchr _ARG_((const void *, int, size_t));
+    extern Void_t *memccpy _ARG_((void *, const void *, int, size_t));
 #ifndef memcpy
-extern Void_t*	memcpy _ARG_((void*, const void*, size_t));
+    extern Void_t *memcpy _ARG_((void *, const void *, size_t));
 #endif
 #if !defined(strtod)
-extern double	strtod _ARG_((const char*, char**));
+    extern double strtod _ARG_((const char *, char **));
 #endif
 #if !defined(remove)
-extern int	remove _ARG_((const char*));
+    extern int remove _ARG_((const char *));
 #endif
-#endif /* !__STDC__ && !_hdr_stdlib */
+#endif				/* !__STDC__ && !_hdr_stdlib */
 
 #if !_hdr_unistd
-extern int	close _ARG_((int));
-extern ssize_t	read _ARG_((int, void*, size_t));
-extern ssize_t	write _ARG_((int, const void*, size_t));
-extern off_t	lseek _ARG_((int, off_t, int));
-extern int	dup _ARG_((int));
-extern int	isatty _ARG_((int));
-extern int	wait _ARG_((int*));
-extern int	pipe _ARG_((int*));
-extern int	access _ARG_((const char*, int));
-extern uint	sleep _ARG_((uint));
-extern int	execl _ARG_((const char*, const char*,...));
-extern int	execv _ARG_((const char*, char**));
+    extern int close _ARG_((int));
+    extern ssize_t read _ARG_((int, void *, size_t));
+    extern ssize_t write _ARG_((int, const void *, size_t));
+    extern off_t lseek _ARG_((int, off_t, int));
+    extern int dup _ARG_((int));
+    extern int isatty _ARG_((int));
+    extern int wait _ARG_((int *));
+    extern int pipe _ARG_((int *));
+    extern int access _ARG_((const char *, int));
+    extern uint sleep _ARG_((uint));
+    extern int execl _ARG_((const char *, const char *, ...));
+    extern int execv _ARG_((const char *, char **));
 #if !defined(fork)
-extern int	fork _ARG_((void));
+    extern int fork _ARG_((void));
 #endif
 #if _lib_unlink
-extern int	unlink _ARG_((const char*));
+    extern int unlink _ARG_((const char *));
 #endif
 
 #endif /*_hdr_unistd*/
 
 #if _lib_bcopy && !_proto_bcopy
-extern void	bcopy _ARG_((const void*, void*, size_t));
+    extern void bcopy _ARG_((const void *, void *, size_t));
 #endif
 #if _lib_bzero && !_proto_bzero
-extern void	bzero _ARG_((void*, size_t));
+    extern void bzero _ARG_((void *, size_t));
 #endif
 
-extern time_t	time _ARG_((time_t*));
-extern int	waitpid _ARG_((int,int*,int));
-extern void	_exit _ARG_((int));
-typedef int(*	Onexit_f)_ARG_((void));
-extern Onexit_f	onexit _ARG_((Onexit_f));
+    extern time_t time _ARG_((time_t *));
+    extern int waitpid _ARG_((int, int *, int));
+    extern void _exit _ARG_((int));
+    typedef int (*Onexit_f) _ARG_((void));
+    extern Onexit_f onexit _ARG_((Onexit_f));
 
 #if _sys_stat
-extern int	fstat _ARG_((int, Stat_t*));
+    extern int fstat _ARG_((int, Stat_t *));
 #endif
 
 #if _lib_vfork && !_hdr_vfork && !_sys_vfork
-extern pid_t	vfork _ARG_((void));
+    extern pid_t vfork _ARG_((void));
 #endif /*_lib_vfork*/
 
 #if _lib_poll
 #if _lib_poll_fd_1
-extern int	poll _ARG_((struct pollfd*, ulong, int));
+    extern int poll _ARG_((struct pollfd *, ulong, int));
 #else
-extern int	poll _ARG_((ulong, struct pollfd*, int));
+    extern int poll _ARG_((ulong, struct pollfd *, int));
 #endif
 #endif /*_lib_poll*/
 
 #if _proto_open && __cplusplus
-extern int	open _ARG_((const char*, int, ...));
+    extern int open _ARG_((const char *, int, ...));
 #endif
 
-#endif /* _PACKAGE_ast */
-
-_END_EXTERNS_
+#endif				/* _PACKAGE_ast */
 
+     _END_EXTERNS_
 #endif /*_SFHDR_H*/
-
 #ifdef __cplusplus
 }
 #endif
