@@ -1,21 +1,14 @@
-/* $Id: getopt.c,v 1.4 2004/12/11 19:26:12 ellson Exp $ $Revision: 1.4 $ */
+/* $Id: getopt.c,v 1.5 2004/12/13 17:19:48 ellson Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
-
 #if !defined(lint) && defined(SCCSIDS)
 static char sccsid[] = "@(#)getopt.c 1.1 90/03/23 SMI";
+/* from 4.3BSD-tahoe 4.9 6/23/89 */
+#endif
+
+/*
+ * Copyright (c) 1989 Sun Microsystems, Inc.
+ */
 /*
  * Copyright (c) 1987 Regents of the University of California.
  * All rights reserved.
